﻿// SWT add a ctrl click to expand / collapse self & children

var templateCache = function () {
    var store = new Object();
    this.get = function (templateName) {
        if (typeof store[templateName] === "undefined") {
            store[templateName] = $("#validationResultTemplates > div." + templateName);
        }

        return store[templateName];
    }

    return this;
}();

function GenerateValidationResult(fileToValidate) {
    var jqResultContainer = templateCache.get("resultContainer").clone().appendTo($("#validationResultDetailsContainer"));
    jqResultContainer.find(".loadingIcon").addClass("loading");
    jqResultContainer.find("div.protocolFilename").text(fileToValidate);
    var jqXml = null;

    this.setXml = function (responseXml) {
        jqXml = $.isXMLDoc(responseXml) ? $(responseXml) : null;
        appendResults();
    };

    this.setFailError = function (failText) {
        jqXml = null;
        appendResults(failText);
    };

    function appendResults(failText) {
        if (jqXml == null || (failText !== undefined && failText !== null && failText.length > 0)) {
            appendCallFailed(failText === undefined ? "Result XML is empty" : failText);
        } else {
            appendCallSuccess();
        }

        jqResultContainer.find(".loading").removeClass("loading");
    }

    function appendCallFailed(failText) {
        jqResultContainer.find("div.resultCountFail, div.resultCountWarning, div.resultCountPass").text("Error");
        jqResultContainer.find("div.resultDetailFail").text(failText).show();
    }

    function appendCallSuccess() {
        var xfwpn = new XmlfwpNodes(jqXml, null);
        if (xfwpn.fails != null && xfwpn.fails.length == 0) {
            jqResultContainer
                .find("input[type=button].viewProtocolButton")
                .removeAttr("disabled")
                .click(function (newEvent) {
                    newEvent.stopPropagation();
                defaultUI.openViewProtocolForm(fileToValidate);
            });
        }

        generateCountResult(jqXml, new XmlfwpNodes(null, xfwpn, true, false, false), jqResultContainer);
        generateCountResult(jqXml, new XmlfwpNodes(null, xfwpn, false, true, false), jqResultContainer);
        generateCountResult(jqXml, new XmlfwpNodes(null, xfwpn, false, false, true), jqResultContainer);
        generateCountResult(jqXml, new XmlfwpNodes(null, xfwpn), jqResultContainer);
    }
}

function generateCountResult(jqXml, xfwpn, jqResultContainer) {
    append(xfwpn, jqResultContainer);

    function append(xfwpn, jqResultContainer) {
        // determine where the data will be shown
        var failData = { show: xfwpn.fails != null, modeData: xfwpn.fails, countContainerClass: "resultCountFail", detailContainerClass: "resultDetailFail" };
        var warnData = { show: xfwpn.warnings != null, modeData: xfwpn.warnings, countContainerClass: "resultCountWarning", detailContainerClass: "resultDetailWarning" };
        var passData = { show: xfwpn.passes != null, modeData: xfwpn.passes, countContainerClass: "resultCountPass", detailContainerClass: "resultDetailPass" };
        var allData = { show: xfwpn.hasMultipleResultTypes, modeData: null, countContainerClass: "resultTextAll", detailContainerClass: "resultDetailAll" };
        var processData = allData;
        if (!allData.show) {
            processData = failData.show ? failData : (warnData.show ? warnData : passData);
        }

        var jqCountContainer = jqResultContainer.find("div." + processData.countContainerClass);
        var jqExpansionArea = jqResultContainer.find("div." + processData.detailContainerClass);

        // Setup the mode count number and click
        if (processData.modeData != null) {
            jqCountContainer.text(processData.modeData.length);
        }

        jqCountContainer[0].expanderFn = function (show, includeChildren) {
            if (typeof this.lazyLoadComplete === "undefined" || !this.lazyLoadComplete) {
                appendProtocolResult(jqExpansionArea, xfwpn);
                this.lazyLoadComplete = true;
            }

            showHideResults.fromCount(jqExpansionArea, show, includeChildren);
        };

        jqCountContainer.bind("click.expander", function (newEvent) { showHideResults.expanderClick(newEvent, jqExpansionArea); });

        function appendProtocolResult(jqResultContainer, xfwpn) {
            jqResultContainer.empty();
            generateSchemaValidationResult(jqResultContainer, new XmlfwpNodes(jqXml.find("Protocol > Schema"), xfwpn));
            generateNodeResult(jqResultContainer, new XmlfwpNodes(jqXml.find("Protocol > Node"), xfwpn));
        }
    }
}

function generateSchemaValidationResult(jqAppendToNode, xfwpn) {
    appendResults(jqAppendToNode, xfwpn);

    function appendResults(jqAppendToNode, xfwpn) {
        if (xfwpn.somethingToShow) {
            var resultNode = templateCache.get("schemaResults").clone();
            setFailWarningPassNodeClassAndValue(resultNode.find("div.nodePassWarningFail"), xfwpn);
            var jqExpander = resultNode.children("div.expander_plus, div.expander_minus");
            var jqExpansionArea = resultNode.find("div.expansionArea");
            var resultList = jqExpansionArea.find("ul.resultList");
            jqExpander[0].expanderFn = function (show, includeChildren) {
                if (typeof this.lazyLoadComplete === "undefined" || !this.lazyLoadComplete) {
                    if (xfwpn.fails != null) { xfwpn.fails.each(function () { resultList.append(generateResultDescription($(this), "validationResultFail")); }); }
                    if (xfwpn.warnings != null) { xfwpn.warnings.each(function () { resultList.append(generateResultDescription($(this), "validationResultWarning")); }); }
                    if (xfwpn.passes != null) { xfwpn.passes.each(function () { resultList.append(generateResultDescription($(this), "validationResultPass")); }); }
                    this.lazyLoadComplete = true;
                }

                showHideResults.fromExpander(this, show, includeChildren);
            };

            jqExpander.bind("click.expander", function (newEvent) { showHideResults.expanderClick(newEvent, jqExpansionArea); });
            jqAppendToNode.append(resultNode);
        }

        function generateResultDescription(jqXmlNode, className) {
            var message = jqXmlNode.children("Message");
            var xpath = jqXmlNode.children("Xpath");
            var text = "";
            if (message.length == 1) { text += message.text(); }
            if (xpath.length == 1) { text += " (xpath:" + xpath.text() + ")"; }
            return $("<li>" + text + "</li>").addClass(className);
        }
    }
}

function generateNodeResult(jqAppendToNode, xfwpn) {
    appendResults(jqAppendToNode, xfwpn);

    function appendResults(jqAppendToNode, xfwpn) {
        if (xfwpn.somethingToShow) {
            var resultNode = templateCache.get("nodeResult").clone();
            setFailWarningPassNodeClassAndValue(resultNode.find("div.nodePassWarningFail"), xfwpn);
            resultNode.children("div.resultHeading").text(generateResultHeading(xfwpn.jqXmlNode));
            var jqExpander = resultNode.children("div.expander_plus, div.expander_minus");
            var jqExpansionArea = resultNode.find("div.expansionArea");
            jqExpander[0].expanderFn = function (show, includeChildren) {
                if (typeof this.lazyLoadComplete === "undefined" || !this.lazyLoadComplete) {
                    appendCheckMessages(jqExpansionArea, new XmlfwpNodes(xfwpn.jqXmlNode.children("Pass, Warning, Fail"), xfwpn));
                    generateRequiredItemResult(jqExpansionArea, new XmlfwpNodes(xfwpn.jqXmlNode.children("Attributes").children("Required"), xfwpn), false);
                    generateValidatedAttributesResult(jqExpansionArea, new XmlfwpNodes(xfwpn.jqXmlNode.children("Attributes").children("Existing"), xfwpn));
                    generateRequiredItemResult(jqExpansionArea, new XmlfwpNodes(xfwpn.jqXmlNode.children("Nodes").children("Required"), xfwpn), true);
                    xfwpn.jqXmlNode.children("Nodes").children("Existing").children("Node").each(function () {
                        generateNodeResult(jqExpansionArea, new XmlfwpNodes($(this), null, xfwpn.hasFails, xfwpn.hasWarnings, xfwpn.hasPasses));
                    });
                    this.lazyLoadComplete = true;
                }

                showHideResults.fromExpander(this, show, includeChildren);
            };

            jqExpander.bind("click.expander", function (newEvent) { showHideResults.expanderClick(newEvent, jqExpansionArea); });
            jqAppendToNode.append(resultNode);
        }

        function appendCheckMessages(jqAppendToNode, xfwpn) {
            var resultNode = templateCache.get("nodeCheckMessages").clone();
            var resultList = resultNode.find("ul.resultList");
            if (xfwpn.fails != null) { xfwpn.fails.each(function () { resultList.append(generateResultDescription($(this), "validationResultFail")); }); }
            if (xfwpn.warnings != null) { xfwpn.warnings.each(function () { resultList.append(generateResultDescription($(this), "validationResultWarning")); }); }
            if (xfwpn.passes != null) { xfwpn.passes.each(function () { resultList.append(generateResultDescription($(this), "validationResultPass")); }); }
            jqAppendToNode.append(resultNode);

            function generateResultDescription(jqXmlNode, className) {
                var note = jqXmlNode.attr("Note");
                var description = jqXmlNode.attr("Description");
                var text = "";
                if (note != null) { text += note; }
                if (description != null) { text += ": " + description; }
                return $("<li>" + text + "</li>").addClass(className);
            }
        }

        function generateResultHeading(jqXmlNode) {
            var name = jqXmlNode.attr("Name");
            var subType = jqXmlNode.attr("SubType");
            var id = jqXmlNode.attr("Id");
            var lineInfo = jqXmlNode.attr("LineInfo");
            var text = "";
            if (name != null) { text += name; }
            if (subType != null) { text += " of type '" + subType + "'"; }
            if (id != null) { text += ", id: '" + id + "'"; }
            if (lineInfo != null) { text += " at " + lineInfo; }
            return text;
        }
    }
}

function generateRequiredItemResult(jqAppendToNode, xfwpn, isRequiredNode) {
    appendResults(jqAppendToNode, xfwpn, isRequiredNode);

    function appendResults(jqAppendToNode, xfwpn, isRequiredNode) {
        if (xfwpn.somethingToShow) {
            var resultNode = templateCache.get("requiredItemResults").clone();
            setFailWarningPassNodeClassAndValue(resultNode.find("div.nodePassWarningFail"), xfwpn);
            resultNode.children("div.resultHeading").text("Required " + (isRequiredNode ? "Child Nodes" : "Attribute"));
            var jqExpander = resultNode.children("div.expander_plus, div.expander_minus");
            var jqExpansionArea = resultNode.find("div.expansionArea");
            jqExpander[0].expanderFn = function (show, includeChildren) {
                if (typeof this.lazyLoadComplete === "undefined" || !this.lazyLoadComplete) {
                    var ulResultList = resultNode.find("ul.resultList");
                    if (xfwpn.fails != null) { xfwpn.fails.each(function () { ulResultList.append(generateResultDescription($(this), "validationResultFail")); }); }
                    if (xfwpn.warnings != null) { xfwpn.warnings.each(function () { ulResultList.append(generateResultDescription($(this), "validationResultWarning")); }); }
                    if (xfwpn.passes != null) { xfwpn.passes.each(function () { ulResultList.append(generateResultDescription($(this), "validationResultPass")); }); }
                    this.lazyLoadComplete = true;
                }

                showHideResults.fromExpander(this, show, includeChildren);
            };

            jqExpander.bind("click.expander", function (newEvent) { showHideResults.expanderClick(newEvent, jqExpansionArea); });
            jqAppendToNode.append(resultNode);
        }

        function generateResultDescription(jqXmlNode, className) {
            var name = jqXmlNode.attr("Name");
            var note = jqXmlNode.attr("Note");
            var text = "";
            if (name != null) { text += "'" + name + "'"; }
            if (note != null) { text += " " + note; }
            return $("<li>" + text + "</li>").addClass(className);
        }
    }
}

function generateValidatedAttributesResult(jqAppendToNode, xfwpn) {
    appendResults(jqAppendToNode, xfwpn);

    function appendResults(jqAppendToNode, xfwpn) {
        if (xfwpn.somethingToShow) {
            var resultNode = templateCache.get("validatedAttributesResults").clone();
            setFailWarningPassNodeClassAndValue(resultNode.find("div.nodePassWarningFail"), xfwpn);
            var jqExpander = resultNode.children("div.expander_plus, div.expander_minus");
            var jqExpansionArea = resultNode.find("div.expansionArea");
            jqExpander[0].expanderFn = function (show, includeChildren) {
                if (typeof this.lazyLoadComplete === "undefined" || !this.lazyLoadComplete) {
                    xfwpn.jqXmlNode.children("Attribute").each(function () {
                        appendAttributeResults(jqExpansionArea, new XmlfwpNodes($(this), xfwpn));
                    });
                    this.lazyLoadComplete = true;
                };

                showHideResults.fromExpander(this, show, includeChildren);
            };

            jqExpander.bind("click.expander", function (newEvent) { showHideResults.expanderClick(newEvent, jqExpansionArea); });
            jqAppendToNode.append(resultNode);
        }

        function appendAttributeResults(jqAppendToNode, xfwpn) {
            if (xfwpn.somethingToShow) {
                var resultNode = templateCache.get("validatedAttributeResults").clone();
                resultNode.find("div.resultHeading").text(generateAttributeNameValueText(xfwpn.jqXmlNode));
                var resultList = resultNode.find("ul.resultList");
                if (xfwpn.fails != null) { xfwpn.fails.each(function () { resultList.append(generateResultDescription($(this), "validationResultFail")); }); }
                if (xfwpn.warnings != null) { xfwpn.warnings.each(function () { resultList.append(generateResultDescription($(this), "validationResultWarning")); }); }
                if (xfwpn.passes != null) { xfwpn.passes.each(function () { resultList.append(generateResultDescription($(this), "validationResultPass")); }); }
                jqAppendToNode.append(resultNode);
            }

            function generateResultDescription(jqXmlNode, className) {
                var note = jqXmlNode.attr("Note");
                var description = jqXmlNode.attr("Description");
                var text = "";
                if (note != null) { text += note; }
                if (description != null) { text += ": " + description; }
                return $("<li>" + text + "</li>").addClass(className);
            }

            function generateAttributeNameValueText(jqXmlNode) {
                var name = jqXmlNode.attr("Name");
                var attrValue = jqXmlNode.attr("AttrValue");
                //var lineInfo = jqXmlNode.attr("LineInfo");
                var text = "";
                if (name != null) { text += "'" + name + "'"; }
                if (attrValue != null) { text += ", value '" + attrValue + "'"; }
                //if (lineInfo != null) { text += " at " + lineInfo; }
                return text;
            }
        }
    }
}

showHideResults = function() {}

showHideResults.expanderClick = function (newEvent, jqExpansionArea) {
    newEvent.stopPropagation();
    newEvent.srcElement.expanderFn(!$(jqExpansionArea).is(":visible"), newEvent.ctrlKey);
};

showHideResults.fromCount = function (jqObjToShow, show, includeChildren) {
    jqObjToShow.toggle(show);
    showHideResults.allChildren(jqObjToShow, show, includeChildren);
};

showHideResults.fromExpander = function (objClicked, show, includeChildren) {
    var jqObjToShow =
        $(objClicked)
            .findIncludeSelf(show ? "div.expander_plus" : "div.expander_minus")
            .toggleClass("expander_plus expander_minus")
            .siblings("div.expansionArea")
            .toggle(show);
    showHideResults.allChildren(jqObjToShow, show, includeChildren);
};

showHideResults.allChildren = function (jqObjsToShow, show, includeChildren) {
    var jqExpanders = jqObjsToShow.find("div.expander_plus, div.expander_minus")
    jqExpanders.each(function () {
        var jqThis = $(this);
        if (this.expanderFn !== "undefined"
            && ((this.firstExpansionComplete !== true && jqThis.attr("data-startExpanded") === "true")
                || (includeChildren
                    && ((show && jqThis.hasClass("expander_plus")) || (!show && jqThis.hasClass("expander_minus")))))) {
            this.expanderFn(show, includeChildren);
            this.firstExpansionComplete = true;
        }
    });
};

function setFailWarningPassNodeClassAndValue(jQueryNodesToSet, xfwpn, setText) {
    setText = typeof setText === "undefined" ? true : setText;
    // Set the worst case value
    if (xfwpn.hasFails) {
        jQueryNodesToSet.addClass("validationResultFail");
        if (setText) { jQueryNodesToSet.text("Fail"); }
    } else if (xfwpn.hasWarnings) {
        jQueryNodesToSet.addClass("validationResultWarning");
        if (setText) { jQueryNodesToSet.text("Warning"); }
    } else if (xfwpn.hasPasses) {
        jQueryNodesToSet.addClass("validationResultPass");
        if (setText) { jQueryNodesToSet.text("Pass"); }
    }
}

function XmlfwpNodes(jqXmlFilterStartNode, existingXmlfwpn, includeFails, includeWarnings, includePasses) {
    includeFails = include(includeFails) && (existingXmlfwpn == null ? true : existingXmlfwpn.fails != null);
    includeWarnings = include(includeWarnings) && (existingXmlfwpn == null ? true : existingXmlfwpn.warnings != null);
    includePasses = include(includePasses) && (existingXmlfwpn == null ? true : existingXmlfwpn.passes != null);
    var that = this;
    this.jqXmlNode = jqXmlFilterStartNode;
    this.fails = getFailType("Fail", existingXmlfwpn == null ? null : existingXmlfwpn.fails, includeFails);
    this.warnings = getFailType("Warning", existingXmlfwpn == null ? null : existingXmlfwpn.warnings, includeWarnings);
    this.passes = getFailType("Pass", existingXmlfwpn == null ? null : existingXmlfwpn.passes, includePasses);
    this.hasFails = this.fails != null && this.fails.length > 0;
    this.hasWarnings = this.warnings != null && this.warnings.length > 0;
    this.hasPasses = this.passes != null && this.passes.length > 0;
    this.somethingToShow = this.hasFails || this.hasWarnings || this.hasPasses;
    this.hasMultipleResultTypes = (this.fails != null ? 1 : 0) + (this.warnings != null ? 1 : 0) + (this.passes != null ? 1 : 0) > 1;

    function include(val) { return val === undefined || val; }

    function getFailType(failType, existingXmlfwpnValues, includeType) {
        var result = null
        if (includeType) {
            if (that.jqXmlNode == null) {
                result = existingXmlfwpnValues == null ? null : existingXmlfwpnValues;
            }
            else {
                result = that.jqXmlNode.findIncludeSelf(failType);
            }
        }

        return result;
    }
}
