<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sup="http://www.show.scot.nhs.uk/isd/Supplementary" xmlns:gen="http://www.show.scot.nhs.uk/isd/General" xmlns:h="http://www.w3.org/1999/xhtml" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:user="http://www.sci.scot.nhs.uk">
    <xsl:output method="text" encoding="utf-8" indent="no"/>
    
    <!-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->
    <msxsl:script language="JScript" implements-prefix="user"><![CDATA[

	function get_month(p_Month)
   {
       var strMonth;

       switch (p_Month) {
       case "01" :
           strMonth = "Jan";
           break;
       case "02" :
           strMonth = "Feb";
           break;
       case "03" :
           strMonth = "Mar";
           break;
       case "04" :
           strMonth = "Apr";
           break;
       case "05" :
          strMonth = "May";
          break;
      case "06" :
          strMonth = "Jun";
          break;
      case "07" :
          strMonth = "Jul";
          break;
      case "08" :
          strMonth = "Aug";
          break;
      case "09" :
          strMonth = "Sep";
          break;
      case "10" :
          strMonth = "Oct";
          break;
      case "11" :
          strMonth = "Nov";
          break;
      case "12" :
          strMonth = "Dec";
          break; 
      default :
          strMonth = "   ";
   } 

  return(strMonth);

}
		function isDate(value)
   {
       return(!isNaN(new Date(value)));  
   }
    
    function UnambiguousDate(p_date)
   {
   
     var dteDate;
     var strDay, strMonth, strYear, strDate;

     // Garaunteed formats
     strDate = new String(p_date);
     strYear = strDate.substring(0,4);  
     strMonth = strDate.substring(5,7);
     strDay = strDate.substring(8,10);
  
     if (isDate(new Date(strYear,strMonth,strDay)))
     {
         return(strDay + "-" + get_month(strMonth) + "-" + strYear);
     }
}   

function FormatHCN(patient_uid)
{
    var strHCN, strOne, strTwo, strThree;
     
    //remove any spaces entered by user
    strHCN = new String(patient_uid.split(' ').join(''));
     
    //get first three characters
    strOne = strHCN.substring(0, 3);
     
    //get next three characters
    strTwo = strHCN.substring(3, 6);
     
    //get next four characters
    strThree = strHCN.substring(6, 10);
     
    //display formatted HCN as XXX XXX XXXX
    return(strOne + " " + strTwo + " " + strThree);
}

    ]]></msxsl:script>
    <!-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->
        
    <xsl:template match="/sup:SupplementaryDocument">
        <xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:PatientName/gen:StructuredName"/>, 
        <xsl:choose>
            <xsl:when test="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:PatientId[gen:IdScheme='CHI']/gen:IdValue">
                <xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:PatientId[gen:IdScheme='CHI']/gen:IdValue"/>,
            </xsl:when>
			<xsl:when test="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:PatientId[gen:IdScheme='HCN']/gen:IdValue">
				<xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:PatientId[gen:IdScheme='HCN']/gen:IdValue"/>,
			</xsl:when>
			<xsl:when test="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:PatientId[gen:IdScheme='NHS Number']/gen:IdValue">
				<xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:PatientId[gen:IdScheme='NHS Number']/gen:IdValue"/>,
			</xsl:when>
        </xsl:choose>,
        <xsl:apply-templates select="/sup:SupplementaryDocument/sup:MessageData/sup:PatientDemographics/gen:DateOfBirth"/>
    </xsl:template>

    <!--
    Template will output "Patient: Unknown" if no FamilyName specified;
    otherwise "FamilyName" if no GivenName is specified; or "FamilyName, GivenName" if GivenName is specified
    -->
    <xsl:template match="gen:StructuredName">
        <xsl:choose>
            <xsl:when test="string-length(gen:FamilyName) > 0">
                <xsl:value-of select="gen:FamilyName"/>
                <xsl:if test="string-length(gen:GivenName) > 0">, <xsl:value-of select="gen:GivenName"/>
                </xsl:if>
            </xsl:when>
            <xsl:otherwise>
                Patient: Unknown
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--
    Template will output "CHI: {IdValue}" if a CHI is specified; otherwise "CHI: Unknown"
    -->
    <xsl:template match="gen:PatientId[gen:IdScheme='CHI']/gen:IdValue">
        <xsl:choose>
            <xsl:when test="string-length(.) > 0">
                CHI: <xsl:value-of select="."/>
            </xsl:when>
            <xsl:otherwise>
                CHI: Unknown
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

	<!--
    Template will output "HCN: {IdValue}" if a HCN is specified; otherwise "HCN: Unknown"
    -->
	<xsl:template match="gen:PatientId[gen:IdScheme='HCN']/gen:IdValue">
		<xsl:choose>
			<xsl:when test="string-length(.) > 0">
				HCN: <xsl:value-of select="user:FormatHCN(string(.))"/>
			</xsl:when>
			<xsl:otherwise>
				HCN: Unknown
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--
    Template will output "NHS #: {IdValue}" if an NHS Number is specified; otherwise "NHS #: Unknown"
    -->
	<xsl:template match="gen:PatientId[gen:IdScheme='NHS Number']/gen:IdValue">
		<xsl:choose>
			<xsl:when test="string-length(.) > 0">
				NHS #: <xsl:value-of select="."/>
			</xsl:when>
			<xsl:otherwise>
				NHS #: Unknown
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
    
    <!--
    Template will output "DateOfBirth" if it is specified; otherwise "DoB: Unknown"
    -->
    <xsl:template match="gen:DateOfBirth">
        <xsl:choose>
            <xsl:when test="string-length(.) > 0">
                <xsl:value-of select="user:UnambiguousDate(string(.))"/>
            </xsl:when>
            <xsl:otherwise>
                DoB: Unknown
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
