<?xml version="1.0" encoding="UTF-8"?>
<!--This stylesheet takes patient detail xml (pms:) and converts it into prepopulation source xml (pps:) -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:pms="http://www.show.scot.nhs.uk/isd/PmsInterface" xmlns:pps="http://www.show.scot.nhs.uk/isd/PrePopulationSource"  xmlns:fn="http://www.w3.org/2005/xpath-functions">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<!-- Map a PATIENT_TYPE (pms: v1.0) to PREPOPULATION_TYPE (pps: v1.4) -->
	<xsl:template match="pms:PatientDetailsDocument">
		<xsl:element name="PrePopulationDocument" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="node()|@*"/>
		</xsl:element>
	</xsl:template>
	<!-- change the root node schema version -->
	<xsl:template match="pms:PatientDetailsDocument/@SchemaVersion">
		<xsl:attribute name="SchemaVersion"><xsl:value-of select="1.4"/></xsl:attribute>
	</xsl:template>
	<!-- Change the pms: namespaces to the pps: namespace -->
	<xsl:template match="pms:*">
		<xsl:element name="{local-name()}" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="node()|@*"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="node()|@*">
		<xsl:if test="./ancestor-or-self::pms:PatientDetailsDocument">	<!-- to ensure we only copy correct namespace elements-->
			<xsl:copy>
				<xsl:apply-templates select="node()|@*"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	<!-- Sort by date and time and map BLOOD_PRESSURES_TYPE (pms: v1.7) to BLOOD_PRESSURES_TYPE (pps: v1.4) -->
	<xsl:template match="pms:BloodPressures">
		<xsl:element name="BloodPressures" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:for-each select="./pms:BloodPressure">
				<xsl:sort select="./pms:RecordedDate" data-type="text" order="descending"/>
				<xsl:sort select="./pms:RecordedTime" data-type="text" order="descending"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<!-- Sort by date and time and map BODY_MEASUREMENTS_TYPE (pms: v1.7) to BODY_MEASUREMENTS_TYPE (pps: v1.4) -->
	<xsl:template match="pms:BodyMeasurements">
		<xsl:element name="BodyMeasurements" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:for-each select="./pms:BodyMeasurement">
				<xsl:sort select="./pms:RecordedDate" data-type="text" order="descending"/>
				<xsl:sort select="./pms:RecordedTime" data-type="text" order="descending"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<!-- Sort by date and time and map PREGNANCY_HISTORY_TYPE (pms: v1.7) to PREGNANCY_HISTORY_TYPE (pps: v1.4) -->
	<xsl:template match="pms:PregnancyHistory">
		<xsl:element name="PregnancyHistory" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:for-each select="./pms:Pregnancies">
				<xsl:sort select="./pms:RecordedDate" data-type="text" order="descending"/>
				<xsl:sort select="./pms:RecordedTime" data-type="text" order="descending"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<xsl:template match="pms:ReferralToTreatmentData">
	<!-- Pull the UCPN out of the referral to treatment data and put it in the Document Data -->
		<xsl:if test="normalize-space(pms:UniqueCarePathwayNumber)!=''">
			<xsl:element name="DocumentData" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:element name="UniqueCarePathwayNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="pms:UniqueCarePathwayNumber"/>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<!-- Now copy all the other RTT data across -->
		<xsl:element name="ReferralToTreatmentData" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="pms:RTTStatus" />
			<xsl:apply-templates select="pms:DateOfOriginalReferral"/>
			<xsl:apply-templates select="pms:DaysElapsed"/>
			<xsl:element name="PeriodsOfFutureUnavailability" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:apply-templates select="pms:PeriodsOfFutureUnavailability"/>
			</xsl:element>
			<xsl:apply-templates select="pms:AdditionalInformation" />
		</xsl:element>
	</xsl:template>
	<xsl:template match="pms:PeriodsOfFutureUnavailability">
		<xsl:element name="PeriodOfFutureUnavailability" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="./*" /> 
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
