<?xml version="1.0" encoding="UTF-8"?>
<!--This stylesheet takes patient detail xml (tpi:) and converts it into prepopulation source xml (pps:) -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tpi="http://www.show.scot.nhs.uk/isd/ThirdPartyInterface" xmlns:pps="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<!-- Map a PATIENT_TYPE (tpi: v1.4) to PREPOPULATION_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:PatientDetailsDocument">
		<xsl:element name="PrePopulationDocument" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="./@SchemaVersion"/>
			<xsl:apply-templates select="tpi:PatientDemographics"/>
			<xsl:apply-templates select="tpi:PatientBackgroundInformation"/>
			<xsl:apply-templates select="tpi:PatientRegistration"/>
			<xsl:apply-templates select="tpi:CurrentEncounterGP"/>
			<xsl:apply-templates select="tpi:PatientClinicalInformation"/>
		</xsl:element>
	</xsl:template>
	<!-- change the root node schema version -->
	<xsl:template match="tpi:PatientDetailsDocument/@SchemaVersion">
		<xsl:attribute name="SchemaVersion">
			<xsl:value-of select="1.4"/>
		</xsl:attribute>
	</xsl:template>
	<!-- Change the tpi namespaces to the pps namespace -->
	<xsl:template match="tpi:*">
		<xsl:element name="{local-name()}" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="node()|@*"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="node()|@*">
		<xsl:if test="./ancestor-or-self::tpi:PatientDetailsDocument">	<!-- to ensure we only copy correct namespace elements-->
			<xsl:copy>
				<xsl:apply-templates select="node()|@*"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	<!-- Map a CLINICAL_INFORMATION_TYPE (tpi: v1.5) to CLINICAL_INFORMATION_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:PatientClinicalInformation">
		<xsl:element name="PatientClinicalInformation" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="tpi:Medication"/>
			<xsl:apply-templates select="tpi:Conditions"/>
			<xsl:apply-templates select="tpi:Procedures"/>
			<xsl:apply-templates select="tpi:FamilyConditions"/>
			<xsl:apply-templates select="tpi:Alerts"/>
			<xsl:apply-templates select="/tpi:PatientDetailsDocument/tpi:PatientMeasurements"/>
		</xsl:element>
	</xsl:template>
	<!-- Map a MEASUREMENTS_TYPE (tpi: v1.4) to MEASUREMENTS_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:PatientMeasurements">
		<xsl:element name="PatientMeasurements" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="./tpi:BloodPressure"/>
			<xsl:apply-templates select="./tpi:BodyMass"/>
			<xsl:apply-templates select="./tpi:Pregnancies"/>
		</xsl:element>
	</xsl:template>
	<!-- Map a BLOOD_PRESSURE_TYPE (tpi: v1.4) to BLOOD_PRESSURES_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:BloodPressure">
		<xsl:element name="BloodPressures" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:element name="BloodPressure" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="./tpi:Diastolic">
					<xsl:element name="Diastolic" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="./tpi:Diastolic"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="./tpi:Systolic">
					<xsl:element name="Systolic" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="./tpi:Systolic"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- Map a BODY_MASS_TYPE (tpi: v1.4) to BODY_MEASUREMENTS_TYPE (pps: v1.4) -->	
	<xsl:template match="tpi:BodyMass">
		<xsl:element name="BodyMeasurements" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:element name="BodyMeasurement" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="./tpi:BodyMassIndex">
					<xsl:element name="BodyMassIndex" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="./tpi:BodyMassIndex"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="./tpi:Height">
					<xsl:element name="Height" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="./tpi:Height"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="./tpi:Weight">
					<xsl:element name="Weight" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="./tpi:Weight"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- Map a PREGNANCIES_TYPE (tpi: v1.4) to PREGNANCY_HISTORY_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:Pregnancies">
		<xsl:element name="PregnancyHistory" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:element name="Pregnancies" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:if test="./tpi:Gravida">
					<xsl:element name="Gravida" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="./tpi:Gravida"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="./tpi:Parity">
					<xsl:element name="Parity" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:value-of select="./tpi:Parity"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
