<?xml version="1.0" encoding="UTF-8"?>
<!--
This stylesheet takes SCI Store GetPatient() XML and transforms to a third party interface format document
FROM - SCI Store interface = 7.1 (SCIStoreGeneral-V7-1.xsd PateintInformation)
TO - Third Party Interface 1.7
-->
<xsl:stylesheet version="1.0" xmlns="http://www.show.scot.nhs.uk/isd/ThirdPartyInterface" xmlns:ss="http://www.show.scot.nhs.uk/isd/SCIStore" xmlns:ssm="http://www.show.scot.nhs.uk/isd/SCIStore/Messages" xmlns:gen="http://www.show.scot.nhs.uk/isd/General" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2005/xpath-functions">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/*">
		<xsl:element name="PatientDetailsDocument">
			<xsl:attribute name="SchemaVersion">1.7</xsl:attribute>
			<xsl:apply-templates select="ssm:PatientInformation/ss:BasicDemographics"/>
			<xsl:apply-templates select="ssm:PatientInformation/ss:SocialCircumstances"/>
			<xsl:apply-templates select="ssm:PatientInformation/ss:ExtendedDemographics"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="ssm:PatientInformation/ss:BasicDemographics">
		<xsl:element name="PatientDemographics">
			<xsl:apply-templates mode="PatientDemographics" select="/*/ssm:SystemInformation/ss:PatientID"/>
			<xsl:apply-templates mode="PatientDemographics" select="gen:PatientId[./gen:IdScheme='CHI'][1]/gen:IdValue"/>
			<xsl:apply-templates mode="PatientDemographics" select="gen:DateOfBirth"/>
			<xsl:choose>
				<xsl:when test ="gen:PatientName[./gen:NameType='Preferred'][1]/gen:StructuredName">
					<xsl:apply-templates mode="PatientDemographics" select="gen:PatientName[./gen:NameType='Preferred'][1]/gen:StructuredName"/>
				</xsl:when>
				<xsl:when test="gen:PatientName[./gen:NameType='Current'][1]/gen:StructuredName">
					<xsl:apply-templates mode="PatientDemographics" select="gen:PatientName[./gen:NameType='Current'][1]/gen:StructuredName"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="PatientDemographics" select="gen:PatientName[1]/gen:StructuredName"/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates mode="PatientDemographicsBirthName" select="gen:PatientName[./gen:NameType='Birth'][1]/gen:StructuredName"/>
			<xsl:apply-templates mode="PatientDemographics" select="gen:Sex"/>
			<xsl:apply-templates mode="PatientDemographics" select="gen:MaritalStatus"/>
			<xsl:choose>
				<xsl:when test="gen:PatientAddress[./gen:AddressType='Current'][1]">
					<xsl:apply-templates mode="PatientDemographics" select="gen:PatientAddress[./gen:AddressType='Current'][1]"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="PatientDemographics" select="gen:PatientAddress[1]"/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates mode="PatientDemographicsPhone" select="gen:PatientTelecom[./gen:TelecomType='Voice'][1]"/>
			<xsl:apply-templates mode="PatientDemographicsMobile" select="gen:PatientTelecom[./gen:TelecomType='Mobile'][1]"/>
			<xsl:apply-templates mode="PatientDemographicsEmail" select="gen:PatientTelecom[./gen:TelecomType='E-mail'][1]"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="ss:PatientID" mode="PatientDemographics">
		<xsl:element name="Key">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientId/gen:IdValue" mode="PatientDemographics">
		<xsl:element name="CHI">
			<xsl:value-of select="substring(., 1, 10)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:DateOfBirth" mode="PatientDemographics">
		<xsl:element name="DateOfBirth">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientName/gen:StructuredName" mode="PatientDemographics">
		<xsl:if test="gen:Title">
			<xsl:element name="Title">
				<xsl:value-of select="substring(normalize-space(gen:Title), 1, 35)"/>
			</xsl:element>
		</xsl:if>
		<xsl:element name="Forename">
			<xsl:value-of select="substring(normalize-space(gen:GivenName), 1, 35)"/>
		</xsl:element>
		<xsl:if test="gen:MiddleName">
			<xsl:element name="Middlename">
				<xsl:value-of select="substring(normalize-space(gen:MiddleName), 1, 35)"/>
			</xsl:element>
		</xsl:if>
		<xsl:element name="Surname">
			<xsl:value-of select="substring(normalize-space(gen:FamilyName), 1, 35)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientName/gen:StructuredName" mode="PatientDemographicsBirthName">
		<xsl:element name="BirthSurname">
			<xsl:value-of select="substring(normalize-space(gen:FamilyName), 1, 35)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:Sex" mode="PatientDemographics">
		<xsl:element name="Sex">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:MaritalStatus" mode="PatientDemographics">
		<xsl:element name="MaritalStatus">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientAddress" mode="PatientDemographics">
		<xsl:element name="Address">
			<xsl:choose>
				<xsl:when test="gen:StructuredAddress">
					<xsl:if test="gen:StructuredAddress/gen:AddressLine[1]">
						<xsl:element name="AddressLine">
							<xsl:value-of select="substring(normalize-space(concat(gen:StructuredAddress/gen:PropertyNumber, ' ', gen:StructuredAddress/gen:AddressLine[1])), 1, 35)"/>
						</xsl:element>
					</xsl:if>
					<xsl:for-each select="gen:StructuredAddress/gen:AddressLine[position() > 1]">
						<xsl:element name="AddressLine">
							<xsl:value-of select="substring(normalize-space(.), 1, 35)"/>
						</xsl:element>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="gen:UnstructuredAddress">
					<xsl:element name="AddressLine">
						<xsl:value-of select="substring(normalize-space(gen:UnstructuredAddress), 1, 35)"/>
						<xsl:if test="string-length(normalize-space(gen:UnstructuredAddress)) > 35">
							<xsl:value-of select="substring(normalize-space(gen:UnstructuredAddress), 35, 70)"/>
						</xsl:if>
					</xsl:element>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="gen:PostCode">
				<xsl:element name="PostCode">
					<xsl:value-of select="gen:PostCode"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientTelecom" mode="PatientDemographicsPhone">
		<xsl:element name="PhoneNumber">
			<xsl:apply-templates select ="." mode="PatientDemographicsTelecom">
				<xsl:with-param name="maxLength" select="35"/>
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientTelecom" mode="PatientDemographicsMobile">
		<xsl:element name="MobileNumber">
			<xsl:apply-templates select ="." mode="PatientDemographicsTelecom">
				<xsl:with-param name="maxLength" select="35"/>
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientTelecom" mode="PatientDemographicsEmail">
		<xsl:element name="EmailAddress">
			<xsl:apply-templates select ="." mode="PatientDemographicsTelecom">
				<xsl:with-param name="maxLength" select="255"/>
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:PatientTelecom" mode="PatientDemographicsTelecom">
		<xsl:param name="maxLength"/>
		<xsl:choose>
			<xsl:when test="gen:StructuredTelecom">
				<xsl:value-of select="substring(normalize-space(concat(gen:StructuredTelecom/gen:TelecomArea,gen:StructuredTelecom/gen:TelecomNo)), 1, $maxLength)"/>
			</xsl:when>
			<xsl:when test="gen:UnstructuredTelecom">
				<xsl:value-of select ="substring(normalize-space(gen:UnstructuredTelecom), 1, $maxLength)"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ssm:PatientInformation/ss:SocialCircumstances">
		<xsl:element name="PatientBackgroundInformation">
			<xsl:element name="SocialCircumstances">
				<xsl:choose>
					<xsl:when test="gen:HousingDetail">
						<xsl:apply-templates select="gen:HousingDetail"/>
					</xsl:when>
					<xsl:when test="gen:Housing">
						<xsl:apply-templates select="gen:Housing"/>
					</xsl:when>
				</xsl:choose>
				<xsl:apply-templates select="gen:Employment"/>
				<xsl:apply-templates select="gen:Religion"/>
				<xsl:apply-templates select="gen:EthnicOrigin"/>
				<xsl:choose>
					<xsl:when test="gen:LanguageDetail">
						<xsl:apply-templates select="gen:LanguageDetail"/>
					</xsl:when>
					<xsl:when test="gen:Language">
						<xsl:apply-templates select="gen:Language"/>
					</xsl:when>
				</xsl:choose>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:Housing">
		<xsl:element name="Housing">
			<xsl:value-of select="substring(normalize-space(.), 1, 198)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:HousingDetail">
		<xsl:element name="Housing">
			<xsl:value-of select="substring(normalize-space(concat(
						  'Type:', substring(normalize-space(gen:Accomodation), 1, 20), 
						  ', Controlled Door:communal:', substring(normalize-space(gen:CommunalControlledDoor), 1, 10), 
						  ';individual:', substring(normalize-space(gen:IndividualControlledDoor), 1, 10), 
						  ', Keypad No:', substring(normalize-space(gen:KeyPadNumber), 1, 20), 
						  ', Alarm:', substring(normalize-space(gen:CommunityAlarm), 1, 10), 
						  ', Smoke alarm:', substring(normalize-space(gen:SmokeAlarm), 1, 10), 
						  ', Tenure:', substring(normalize-space(gen:Tenure), 1, 20), 
						  ', Composition:', substring(normalize-space(gen:HouseholdComposition), 1, 20))), 1, 198)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:Employment">
		<xsl:element name="Employment">
			<xsl:element name="Description">
				<xsl:value-of select="substring(normalize-space(.), 1, 70)"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:Religion">
		<xsl:element name="Religion">
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:EthnicOrigin">
		<xsl:element name="EthnicOrigin">
			<xsl:value-of select="substring(normalize-space(.), 1, 70)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:Language">
		<xsl:element name="Language">
			<xsl:value-of select="substring(normalize-space(.), 1, 70)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="gen:LanguageDetail">
		<xsl:element name="Language">
			<xsl:value-of select="substring(normalize-space(concat(
						  'Pref:', substring(normalize-space(gen:PreferredLanguage), 1, 35), 
						  ', Interpreter Req:', substring(normalize-space(gen:InterpreterRequired), 1, 10))), 1, 70)"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="ssm:PatientInformation/ss:ExtendedDemographics">
		<!-- Nothing from here matches to Third Party Interface XML-->
	</xsl:template>
</xsl:stylesheet>
