'============================================================================================
' File name:        common.vbs
' Description:      Common routines.
'============================================================================================

Option Explicit

'Client side limiter for uploads (also enforced server side)
Const MAXIMUM_ATTACHMENT_SIZE = 2048

'Not 1000 like you'd expect
Const BYTES_PER_KILOBYTE = 1024

'Default DOB used in tbl_lite_service_request
Const DEFAULT_DOB = "30/12/1899 00:00:00"

'The minimum version of Docman required for Gateway interface
Const DOCMAN_MINIMUM_VERSION = 71215

Const S_IN_GPASS = "S_InGpass"      'const also exists server side

'Windows that should be closed when user logs off
Const WINDOWS_TO_CLOSE = "letter;viewmessage;filterstatusandflags"

' Update Author  : S.Craig (RTEL)
' Update Date    : 16/04/2004
' Update Comment : Defect#52005 - Moving referral and discharge constants from
'                  chooseprotocol.vbs to common.vbs since they are used in more than
'                  one vbs file.
Const MSG_REFERRAL  = "1"

'Destination server_path (for redirection)
Dim destination_server_path 

'Carriage Return + Line Feed
Dim CRLF
CRLF = chr(13) & chr(10)

'Variable to hold reference to Change Status window
Dim m_objStatusWin      'As Window
Set m_objStatusWin = Nothing

'Variable to hold reference to Filter (status and flags) window
Dim m_objFilterWin      'As Window
Set m_objFilterWin = Nothing

Sub DebugWrite(strDebugMessage)
'
' Description:  Writes a debug message
' Parameters:   strDebugMessage - Debug message
'    
    Dim lngCount    'As Long
    Dim objRow      'As Row
    Dim objCell     'As Cell
    Dim strClass    'As String
    
    On Error Resume Next
    If Not OBJ_DEBUG_WINDOW Is Nothing Then
        lngCount = OBJ_DEBUG_WINDOW.document.all("debugMsg").rows.length - 1
        strClass = OBJ_DEBUG_WINDOW.document.all("debugMsg").rows(lngCount).className
        Set objRow = OBJ_DEBUG_WINDOW.document.all("debugMsg").insertRow()
        
        If strClass = "listeven" Then
            objRow.className = "listodd"
        Else
            objRow.className = "listeven"
        End If
        
        Set objCell = objRow.InsertCell
        objCell.valign = "top"
        objCell.innerHTML = "<b>" & CStr(lngCount) & "</b>"
        
        If Len(strDebugMessage) > 500 Then
            objRow.InsertCell.innerText = Left(strDebugMessage, 500) & " ..."
        Else
            objRow.InsertCell.innerText = strDebugMessage
        End If
        
        objRow.scrollIntoView
        OBJ_DEBUG_WINDOW.document.all("msg").value = CStr(lngCount)
        OBJ_DEBUG_WINDOW.document.all("msgM").click
        Set objRow = Nothing
        Set objCell = Nothing
    End If
    On Error Goto 0    
End Sub

Function GetGpassPatientKey()   'As String
'
' Description:  Wrapper function to retrieve the Gpass patient key, a hidden element 
'               populated by the Gpass Consulting Room Extension
' Parameters:   None
' Returns:      Patient key
' 
    GetGpassPatientKey = ""
    If Not document.all("GpassPatientKey") Is Nothing Then
        GetGpassPatientKey = document.all("GpassPatientKey").value
    End If
End Function

Function GetGpassPatientName()   'As String
'
' Description:  Wrapper function to retrieve the Gpass patient key, a hidden element 
'               populated by the Gpass Consulting Room Extension
' Parameters:   None
' Returns:      Patient name
' 
    GetGpassPatientName = ""
    If Not document.all("GpassPatientName") Is Nothing Then
        GetGpassPatientName = document.all("GpassPatientName").value
    End If
End Function

Function getType(name)
'
' Description:  Returns the type of an html DOM element
' Parameters:   name - element name
' Returns:      Type
' 
    On Error Resume Next

    Dim strType
    
    If name <> "" Then
        err.number = 0
        
        'Get the type
        strType =  document.all(name).type
        
        If err.number = 0 Then
            getType = strType
        Else
            err.number = 0
            getType = ""
        End If        
    End If
    
    On Error Goto 0    
End Function

Function FormatDate(strDate, isXsd)
'
' Description:  Formats a date to show the month as an abbreviated word
' Parameters:   strDate -
'               isXsd -
' Returns:      Formatted date
'
	Dim varDateSplit
	Dim varDay, varMonth, varYear
	Dim intDay, intMonth, intYear
	Dim strDateOut

	'Return input if all else fails
	strDateOut = strDate

	If IsDate(strDate) Then
		'Split on delimiter
		If InStr(1, strDate, "-") > 0 Then
			varDateSplit = Split(strDate, "-")
		ElseIf InStr(1, strDate, "/") > 0 Then
			varDateSplit = Split(strDate, "/")
		ElseIf InStr(1, strDate, "_") > 0 Then
			varDateSplit = Split(strDate, "_")
		End If

		'Has split OK
		If IsArray(varDateSplit) Then
			'Date has 3 elements
			If LBound(varDateSplit) = 0 And UBound(varDateSplit) = 2 Then
				If isXsd Then
					varDay = varDateSplit(2)
					varYear = varDateSplit(0)
				Else
					varDay = varDateSplit(0)
					varYear = varDateSplit(2)				
				End If
				varMonth = varDateSplit(1)
                       
				'If the three elements are numeric
				If IsNumeric(varDay) And IsNumeric(varMonth) And IsNumeric(varYear) Then
					intDay = CInt(varDay)
					intMonth = CInt(varMonth)
					intYear = CInt(varYear)
               
					'Format as "31 Jan 01" or "02 May 1998" depending on input
					'No guesses made about Y2K
					strDateOut = _
					intDay & " " & _
					MonthName(intMonth, true) & " " & _
					intYear
				End If
			End If                       
		End If
	End If
  
	FormatDate = strDateOut
End Function



Sub SaveLetterToLocalFile(letterHtml, letterTitle, messageTypeName, messageId)

    Dim objPrint
    Dim strDefaultName
 
    'Construct a default filename based on the 
    'message name and message_id
    If CStr(messageId) <> "" Then
        strDefaultName = messageTypeName & CStr(messageId) & ".html"
    End If

    'Create letter document from html string
    Dim iFrameDocToSave
    Set iFrameDocToSave = CreateLetterDocument(letterHtml, letterTitle)
    
    'Open dialog to save the document to a file
    iFrameDocToSave.execCommand "saveas",true, strDefaultName
    
End Sub

Function CreateLetterDocument(letterHtml, letterTitle)
'
' Description:  Create a hidden IFrame in the document to create a copy of the letter, 
' Parameters:   None
' Returns:      The new document.
'
    'Create the new iframe to hold a copy of the letter
    Dim iFrame, iFrameDoc, iFrameId
    Randomize
    iFrameId = "iFrame" & Timer * 100 & Rnd()    'just to make it random
    Set iFrame = document.createElement("<IFRAME id=""" & iFrameId & """ style=""DISPLAY: none;""></IFRAME>")
    Set iFrame = document.body.appendChild(iFrame)
    Set iFrame = document.frames(iFrameId)
    Set iFrameDoc = iFrame.document
    
    'Some letter stylesheets add the html tag and others dont! If it is not there then add it for consistency.
    If Not InStr(LCase(letterHtml), "<html") > 0 Then
        letterHtml = "<HTML><HEAD><TITLE>" & letterTitle &_
                     "</TITLE><META content=""text/html; charset=iso-8859-1"" http-equiv=Content-Type></HEAD>" &_
                     letterHtml &_
                     "</HTML>"
    End If

    'Populate the iframe document with the letter html
    iFrameDoc.Open
    iFrameDoc.write(letterHtml)
    iFrameDoc.title = iFrameDoc.title & " - Saved"
    iFrameDoc.Close
    
    Set CreateLetterDocument = iframeDoc
End Function

Sub UnambiguousDateEntry(objField)
'
' Description:  Will convert a date (string) entry in an input field into an unambiguous string
'               (e.g. 2-3-05 becomes 02-Mar-2005)
' Parameters:   objField - the control containing the value to be formatted (e.g. a text box)
'
    Dim dtDate
    
    If isDate(objField.value) Then
        dtDate = CDate(objField.value)
        objField.value = UnambiguousDate(dtDate)
    End If
End Sub

Sub DateOfBirthUnambiguousDateEntry(objField)
'
' Description:  Will convert a date (string) entry in an input field into an unambiguous string
'               (e.g. 2-3-05 becomes 02-Mar-2005)
'               Same as UnambiguousDateEntry but calls UpdateTitle as this is used when the date field is
'               for patient date of birth to display the patients details in the title bar
' Parameters:   objField - the control containing the value to be formatted (e.g. a text box)
'
    UnambiguousDateEntry(objField)
        
    setTimeout "UpdateTitle()", 0 
End Sub

Function UnambiguousDate(dteDate)
'
' Description:  Formats a date to show abbreviated date part.
' Parameters:   dteDate - date to format
' Returns:      
'
    Dim strDay           'As String
    Dim strMonth         'As String
    Dim strYear          'As String

    UnambiguousDate = ""
    On Error Resume Next    'Trap errors if say an object parameter was provided instead
        If Not IsNull(dteDate) Then
            If IsDate(dteDate) Then
                If Day(dteDate) < 10 Then
                    strDay = "0" & CStr(Day(dteDate))
                Else
                    strDay = CStr(Day(dteDate))    
                End If    
                strMonth = MonthName(Month(dteDate), True)
                strYear = CStr(Year(dteDate))
            
                UnambiguousDate = strDay & "-" & strMonth & "-" & strYear
            End If
        End If
    On Error Goto 0
End Function

Function gpassIsRunning()   'As Boolean
'
' Description:  Checks if Gpass is running.
' Parameters:   None
' Returns:      True/False
'
    Dim objGpass
    
    gpassIsRunning = False
    Set objGpass = Nothing
    
    On Error Resume Next
    
    Set objGpass = getObject(,"NewGpass.Application")
    If not objGpass Is Nothing Then
        gpassIsRunning = True
    Else 
        gpassIsRunning = False
    End If
    
    err.clear
    On Error Goto 0    
End Function

Function getGpassIfRunning(objGpass)    'As Boolean
'
' Description:  Returns a Gpass application object but only if Gpass is already running.
' Parameters:   objGpass -
' Returns:      Gpass application object
' 
    getGpassIfRunning = False
    Set getGpassIfRunning = Nothing
    
    On Error Resume Next
    
    Set objGpass = getObject(,"NewGpass.Application")
    If Not objGpass Is Nothing Then
        getGpassIfRunning = True
    Else
        getGpassIfRunning = False
    End If
    
    err.clear
    on Error Goto 0
End Function

Function In_Gpass() 'As Boolean
'
' Description:  Determines whether or not we are running in the Gpass consulting room extension.
' Parameters:   None
' Returns:      True/False
' 
    Dim strInGpass
    Dim blnInGpass
    
    In_Gpass = False
    If Not document.all("fldInGpass") Is Nothing Then
        strInGpass = document.all("fldInGpass").value
        If strInGpass = S_IN_GPASS Then
            In_Gpass = True
        End If
    End If
End Function

Function GetHandleToWindow(ByVal strURLs, ByRef arrobjWindows)
'
' Description:  Gets handles to open windows
' Parameters:   strURLs - ";" delimited string containing partial (or full!!) urls
'               arrobjWindows - Array or HTMLWindow2 objects
' Returns:      Number of elements in arrobjWindows.
'               Note: Number of elements is one more that upper index of arrobjWindows.
' 
    Dim objShell
    Dim objWins
    Dim objWin
    Dim arrSearch
    Dim arrObjWins()
    Dim lngSearchNmbr
    Dim lngWinCount
    Dim lngArrCount
    Dim objTempWin
    Dim lngSearchSize
    Dim strObjWinTypename
    
    Redim arrObjWins(5)
    
    arrSearch = Split(strURLs, ";")
    lngSearchSize = UBound(arrSearch)
    
    On Error Resume Next
    Set objShell = CreateObject("Shell.Application")
    
    'If we are unable to create Shell.Application (possibly because we're running
    'under WinNT 4.0 without Desktop Update then return Null to indicate that there
    'are no windows
    If Err.Number <> 0 Then
		GetHandleToWindow = 0
		Exit Function
    End If
    
    Set objWins = objShell.Windows

	On Error Resume Next    
    lngWinCount = 0
    For lngArrCount = 0 to lngSearchSize
        For Each objWin in objWins
            'Only interested in browser windows
            strObjWinTypename = LCase(typename(objWin.document))
            If CBool(InStr(strObjWinTypename, "htmldocument")) Then
                If CBool(InStr(LCase(objWin.document.url), arrSearch(lngArrCount))) Then
					If lngWinCount > Ubound(arrObjWins) Then
						Redim Preserve arrObjWins(lngWinCount + 5)
					End If
					
                    Set objTempWin = objWin.document.parentWindow
                    Set arrObjWins(lngWinCount) = objTempWin
                    lngWinCount = lngWinCount + 1
                End If
            End If
        Next
    Next
    
	Redim Preserve arrObjWins(lngWinCount-1)
	arrobjWindows = arrObjWins
	GetHandleToWindow = lngWinCount
	
    On Error Goto 0
    
    Set objShell = Nothing
    Set objWins = Nothing
    Set objTempWin = Nothing
End Function

Function GetUniqueId()
'
' Description:  Creates a unique identifier from the session key
' Parameters:   None
' Returns:      10 char unique Id
' 
    Dim strUniqueID

    'TT54044 - Changed from window.self.fldSession
    strUniqueID = Mid(document.all("fldSession").value, 51 ,10)
    'Replace special characters within the Id to something more sensible
    strUniqueID = Replace(strUniqueID, "=", CStr(Asc("=")))
    strUniqueID = Replace(strUniqueID, "/", CStr(Asc("/")))
    strUniqueID = Replace(strUniqueID, "+", CStr(Asc("+")))
    
    GetUniqueId = strUniqueID
End Function

Function encodeHTML(strString) 'As String
'
' Description:  Converts special characters for use in building HTML strings
' Parameters:   strString - String to convert
' Returns:      Converted string
' 
    strString = replace(strString, "&", "&amp;")
    strString = replace(strString, "<", "&lt;")
    strString = replace(strString, ">", "&gt;")
    strString = replace(strString, "'", "&#39;")        
    strString = replace(strString, """", "&quot;")
    strString = Replace(strString,  "`", "&#96;")
    encodeHTML = strString
End Function

Function encodeVBS(strString) 'As String
'
' Description:  Used to convert singlequotes for use in VBscript
' Parameters:   strString - String to convert
' Returns:      Converted string
'
    strString = replace(strString, "'", "''")       
    strString = replace(strString, "&#39;", "''")       
    strString = replace(strString, "&amp;", "&")                
    encodeVBS = strString
End Function

Function decodeHTML(strString) 'as string
'
' Description:  Converts special characters for use in building HTML strings
' Parameters:   strString - String to convert
' Returns:      Converted string
'
    strString = replace(strString, "&amp;", "&")
    strString = replace(strString, "&lt;", "<")
    strString = replace(strString, "&gt;", ">")
    strString = replace(strString, "&#39;", "'") 
    strString = replace(strString, "&quot;", """")
    strString = Replace(strString, "&#96;",  "`")
    decodeHTML = strString
End Function

Sub EnableDisableButtons(strStartObj, blnDisabled)
'
' Description:  Sets all the buttons in the specified tree structure to enabled or disabled.
' Parameters:   strStartObj - A string containing the id of the object which to start the recursion for button checks
'               blnDisabled - True/False if True the buttons are disabled if False then they are enabled.
'
	Dim startObj
	Set startObj = document.all(strStartObj)
	If startObj Is Nothing Then
		window.alert("Script object " & strObj & " not found")
	Else
		'Check for all objects which are either type "input" or "button"
		Dim ctrl
		Dim foundButton
		For Each ctrl in startObj.children
			'Check if recursion through this branch is required
			If ctrl.children.length > 0 Then
				call EnableDisableButtons(ctrl.uniqueId, blnDisabled)
			End If
			
			'Check if control is a button
			If LCase(ctrl.tagName) = "input" Then
				If LCase(ctrl.type) = "button" Or LCase(ctrl.type) = "submit" Then
					foundButton = true
				End If
			ElseIf LCase(ctrl.tagName) = "button" Then
				If LCase(ctrl.type) = "button" Then
					foundButton = true
				End If
				'In case we are using a table cell...
		    ElseIf LCase(ctrl.className) = "buttonup" _
		            Or LCase(ctrl.className) = "smallbuttonup" _
		            Or LCase(ctrl.className) = "tinybuttonup" _
		            Or LCase(ctrl.className) = "buttondn" _
		            Or LCase(ctrl.className) = "smallbuttondn" _
		            Or LCase(ctrl.className) = "tinybuttondn" Then
		        foundButton = true
			Else
				foundButton = false
			End If
			
			'If control is a button, enable or disable it
			If foundButton = true Then
				ctrl.disabled = blnDisabled
			End If
		Next
	End If
End Sub

'Adds an entry to the audit log
Sub AddToAuditLog(lngMessageId, intEventTypeId, strEventInfo, strSessionID, strGatewayServices)
'
' Description:  Adds an entry to the audit log
' Parameters:   lngMessageId -
'               intEventTypeId -
'               strEventInfo -
'               strSessionID -
'               strGatewayServices -
'
	Dim strXmlRequest
	Dim strXmlResponse
	
	strXmlRequest = "<updateAuditLog_request>" & vbNewline & _
					"<messageid>" & CStr(lngMessageId) & "</messageid>"  & vbNewline & _
					"<eventtypeid>" & CStr(intEventTypeId) & "</eventtypeid>"  & vbNewline & _
					"<eventinfo>" & CStr(strEventInfo) & "</eventinfo>"  & vbNewline & _
					"</updateAuditLog_request>"

	Set strXmlResponse = runFallbackWithSession(strXmlRequest, strGatewayServices, strSessionID)
End Sub

'Just so the vbscript function can be used from javascript
Function VBTypeName(obj)
    VBTypeName = TypeName(obj)
End Function

'Just so the vbscript function can be used from javascript - the vbArrayREsult is a ByRef parameter, which doesn't work in javascript
Function VBGetHandleToWindow(ByVal strURLs)
    Dim vbArrayResult
    Dim resultCount
    resultCount = GetHandleToWindow(strURLs, vbArrayResult)
    VBGetHandleToWindow = vbArrayResult
End function

Function VBMessageBox(prompt, buttons, title)
    Call MsgBox(prompt, buttons, title)
End Function

'Returns boolean indicating if element passed is of type passed.
Function VBMatchElementType(elementName, elementType)
    VBMatchElementType = TypeName(document.all(elementName)) = elementType
End Function
