'============================================================================================
' File name:        validateDate.vbs
' Created:          30-Oct-2002
' Author:           Vincent Curran
' Description:      Provides a function to validate specified dates
' Dependencies:     
' Issues:           
'============================================================================================



'=============================================================================
' Function IsValidDateOfBirth
' Description:  Checks that the Date of Birth is not in the future
'               
' Pass:         [in]  dateOfBirth   - patient's date of birth
' 
'        
' Return:       True if Date of Birth is Valid
' Raise Errors: None
'---------------------------------------------
' Date          Developer           Comments
' 30-Oct-2002   Vincent Curran        
'---------------------------------------------

Function IsValidDateOfBirth(dateOfBirth, message)
    Dim todaysDate     ' as Date
    Dim dtMaxYear
    Dim dtMinYear
    'Assume valid unless found otherwise

    IsValidDateOfBirth = True

    todaysDate = Date()
    dtMinYear = 1753

'Ensure date given is a valid date
    If Not IsDate(dateOfBirth) Then
	    IsValidDateOfBirth = False 
	    message = "Date is invalid"
	    Exit Function
    End If
    
' Compare date of birth with current date
' It is assumed that a referral or discharge could feasibly be made on the day a person was born
' i.e. A date of birth equal to the current date is valid

    If CDate(dateOfBirth) > CDate(todaysDate) Then
        message = "Date of birth cannot be later than referral date"
	    IsValidDateOfBirth = False 
        Exit Function
    End If
    
' Earliest valid SQL date is 1/1/1753
    If Year(dateOfBirth) < dtMinYear Then
        message = "Must be after 1/1/1753"
        IsValidDateOfBirth = False 
	    Exit Function
    End If
End Function

'=============================================================================
' Function IsValidReferralDate
' Description:  Checks that the Referral Date is not in the future
'               
' Pass:         [in]  referralDate   - date of referral
' 
'        
' Return:       True if referral date is Valid
' Raise Errors: None
'---------------------------------------------
' Date          Developer           Comments
' 28-Jun-2010   Laura McNicol        
'---------------------------------------------

Function IsValidReferralDate(referralDate)
    Dim todaysDate     ' as Date
    'Assume valid unless found otherwise

    IsValidReferraLDate = True

    todaysDate = Date()

    If Not IsDate(referralDate) Then
	IsValidReferralDate = False 
	Exit Function
    End If

' Compare referral date with current date
' A referral date equal to the current date is valid

    If CDate(referralDate) > CDate(todaysDate) Then
	IsValidReferralDate = False 
        Exit Function
    End If
End Function