<?xml version="1.0" encoding="UTF-8"?>
<!-- =========================================================
 File:			protocolform.xslt
 Description:	XSLT stylesheet for transforming protocol XML into a tabulated HTML form.
				Be careful of creating white space within the code.
========================================================= -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:user="mailto:dorothee.huck@gpass.co.uk" exclude-result-prefixes="user msxsl">
	<xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes"/>
	<!-- Paths to utilities and graphics used -->
	<xsl:variable name="helpicon" select="'../graphics/help.gif'"/>
	<xsl:variable name="spacer" select="'../graphics/hidden.gif'"/>
	<xsl:variable name="dateicon" select="'../graphics/date.gif'"/>
	<xsl:variable name="spellicon" select="'../graphics/spell.gif'"/>
	<xsl:variable name="deleteicon" select="'../graphics/delete.gif'"/>
	<xsl:variable name="calendar" select="'../utility/popcjs.htm'"/>
	<xsl:variable name="newmsg" select="'false'"/>
	<xsl:variable name="enablespellcheck" select="'false'"/>
	<xsl:variable name="showgpquestions" select="'false'"/>
	<xsl:variable name="isrequestinghcp" select="'false'"/>
	<!-- =========================================================
	 Name:			Protocol
	 Description:	The protocol definition. Look for category elements.
	 ========================================================= -->
	<xsl:template match="gwInternalProtocol">
		<xsl:variable name="renderVersion" select="@renderVersion"/>
		<xsl:if test="@renderVersion='1'">
			<xsl:call-template name="gwInternalProtocolV1"/>
		</xsl:if>
		<xsl:if test="@renderVersion>'1'">
			<xsl:call-template name="gwInternalProtocolV2"/>
		</xsl:if>
	</xsl:template>
	<xsl:template name="gwInternalProtocolV1">
		<!-- Date picker -->
		<script language="javascript">
		
		// Function to display the date-picker calendar to the user	 
		function ShowCalendar(objTakeDateFrom, objSetDateOn)
		{
			// Make the calendar container visible
			popupContainer.style.display = "inline";

			// Open the javascript calendar and give it focus
			popFrame.fPopCalendar(objTakeDateFrom, objSetDateOn, popupContainer);
			popupContainer.firstChild.focus();
			
			// Attach handler for clicks outside the iframe
			popupContainer.firstChild.onblur = HideCalender;
		}
		
		// Handler for when the calendar iframe is deselected
		function HideCalender()
		{	
			// Make calendar invisible
			popupContainer.style.display = "none";
		}
		
	</script>
		<!-- Spell checker -->
		<script language="javascript">
		
		 // Function to display the spell check dialog to the user - text areas
		function SpellCheck(objTextControl)
		{
		RunSpellCheck(objTextControl);
		}

		 // Function to display the spell check dialog to the user	 
		function SpellCheckColumn(sTableId, sColumnId)
		{
		RunSpellCheckColumn(sTableId, sColumnId);
		}
		
	</script>
		<div id="popupContainer" style="display:none; position:absolute; Z-INDEX: 101;">
			<iframe name="popFrame" src="{$calendar}" style="height:190px; width:180px;"/>
		</div>
		<!-- Tab Bar -->
		<div class="tabBar">
			<table cellspacing="0" cellpadding="0">
				<tr height="17">
					<!-- Output tabs -->
					<xsl:apply-templates select="./category" mode="tab"/>
					<td width="100%"/>
				</tr>
			</table>
			<span id="tabBar"/>
			<table cellspacing="0" width="100%">
				<tr>
					<td height="1px" bgcolor="black"/>
				</tr>
				<tr>
					<td class="protocolTitle">
						<xsl:value-of select="@name"/> (v<xsl:value-of select="@version"/>)</td>
				</tr>
			</table>
		</div>
		<!-- Referral data-entry form placeholder -->
		<form name="formRef" method="post">
			<!-- Hidden fields for protocol name, region, and version -->
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name">protocol_name</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@name"/></xsl:attribute>
			</xsl:element>
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name">protocol_region</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@region"/></xsl:attribute>
			</xsl:element>
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name">protocol_version</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@version"/></xsl:attribute>
			</xsl:element>
			<!-- Holder for tab index -->
			<input type="hidden" id="tabIndexStore" value="divTabControl_1"/>
			<!-- Transform category elements -->
			<xsl:apply-templates select="./category" mode="page"/>
		</form>
		<xsl:apply-templates select="/gwInternalProtocol/messagexml/prtobjcts/hdnflds"/>
	</xsl:template>
	<xsl:template match="/sciGatewayProtocol | /protocol">
		<!-- ensure that we ignore the external protocol formats and only use internal format protocol xml -->
	</xsl:template>
	<!-- =========================================================
	 Name:			\protocol\category
	 Description:	Categories within the protocol. The category represents the highest level of division within the protocol definition. For page categories
					output tab flags, and then recurse down, outputting a heading, then free text, questions, and sub-categories. 
	 ========================================================= -->
	<!-- Output tabs for page level categories =========================== -->
	<xsl:template match="category" mode="tab">
		<td>
			<img src="{$spacer}" width="1"/>
		</td>
		<xsl:element name="td">
			<xsl:attribute name="class">tab</xsl:attribute>
			<xsl:attribute name="id">tab_<xsl:value-of select="position()"/></xsl:attribute>
			<xsl:attribute name="nowrap">true</xsl:attribute>
			<xsl:attribute name="onclick">goTab(<xsl:value-of select="position()"/>)</xsl:attribute>
			<!-- Highlight the first tab -->
			<xsl:if test="position()=1">
				<xsl:attribute name="style">color:white;background-color:#000066;</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="@text"/>
		</xsl:element>
	</xsl:template>
	<!-- Output elements for page level categories ======================== -->
	<xsl:template match="category" mode="page">
		<xsl:element name="div">
			<xsl:attribute name="class">categoryContent</xsl:attribute>
			<xsl:attribute name="id">divTabControl_<xsl:value-of select="position()"/></xsl:attribute>
			<!-- Make the first tab visible -->
			<xsl:if test="position()=1">
				<xsl:attribute name="style">visibility:visible;</xsl:attribute>
			</xsl:if>
			<!-- Add hidden tab flag -->
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="id">tabName_<xsl:value-of select="@text"/></xsl:attribute>
				<xsl:attribute name="name"><xsl:value-of select="@text"/></xsl:attribute>
			</xsl:element>
			<!-- Apply standard category processing -->
			<xsl:apply-templates select=".">
				<xsl:with-param name="level" select="1"/>
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>
	<!-- Process normal category elements ==================================== -->
	<xsl:template match="category">
		<xsl:param name="level" select="3"/>
		<!-- Select the heading to output based on the level -->
		<xsl:choose>
			<xsl:when test="$level &gt;= 3">
				<!-- anything lower than 3 defaults to <h3> -->
				<xsl:element name="h3">
					<xsl:value-of select="@text"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="h{$level}">
					<xsl:value-of select="@text"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
		<!-- Apply templates for elements found within categories -->
		<xsl:apply-templates select="./freeText"/>
		<xsl:apply-templates select="./control"/>
		<xsl:apply-templates select="./question"/>
		<xsl:apply-templates select="./category">
			<xsl:with-param name="level" select="$level + 1"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- =========================================================
	 Name:			Free text templates
	 Description:	Header & footer is displayed and space is set for the 
					main form division. The datepicker division is set up. 
	 ========================================================= -->
	<xsl:template match="* | @* | text()">
		<xsl:copy>
			<xsl:apply-templates select="* | @* | text()"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="freeText">
		<xsl:apply-templates select="*"/>
	</xsl:template>
	<!-- =========================================================
	Name: GenericQuestion
	Description: used for generic questions
	============================================================ -->
	<xsl:template name="genericQuestion">
		<xsl:call-template name="stdquestion">
			<xsl:with-param name="caption" select="@text"/>
			<xsl:with-param name="help" select="help"/>
			<xsl:with-param name="mandatory" select="@mandatory"/>
			<xsl:with-param name="spellCheck" select="@spellCheck"/>
			<xsl:with-param name="hidden">
				<xsl:choose>
					<!-- Outputs a multi-line text box -->
					<xsl:when test="@type='hidden'">
						<xsl:value-of select="'true'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@hidden"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="id" select="@id"/>
			<xsl:with-param name="userinput">
				<xsl:choose>
					<!-- Outputs a multi-line text box -->
					<xsl:when test="@type='textArea'">
						<xsl:element name="textArea">
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<xsl:choose>
								<!-- Sets row height -->
								<xsl:when test="@rows!=''">
									<xsl:attribute name="rows"><xsl:value-of select="@rows"/></xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="rows">6</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:if test="@onkeydown != ''">
								<xsl:attribute name="onkeydown"><xsl:value-of select="@onkeydown"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="@readonly = 'true'">
								<xsl:attribute name="readonly">true</xsl:attribute>
							</xsl:if>
							<xsl:if test="normalize-space(@mandatory) = 'true'">
								<xsl:attribute name="class">mandText</xsl:attribute>
								<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
							</xsl:if>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/>
						</xsl:element>
						<xsl:for-each select="./button">
							<xsl:call-template name="btnTemplate">
								<xsl:with-param name="id" select="@id"/>
								<xsl:with-param name="name" select="@name"/>
								<xsl:with-param name="onclick" select="@onclick"/>
								<xsl:with-param name="imgsrc" select="@src"/>
								<xsl:with-param name="value" select="@value"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:when>
					<!-- Outputs a text box -->
					<xsl:when test="@type='text'">
						<xsl:element name="input">
							<xsl:attribute name="type"><xsl:value-of select="@type"/></xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<!-- the document title needs to be updated to reflect any changes to the patient surname -->
							<xsl:if test="@id = 'patient_surname'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<!-- the document title needs to be updated to reflect any changes to the patient forname -->
							<xsl:if test="@id = 'patient_forename'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<!-- the document title needs to be updated to reflect any changes to the patient chi -->
							<xsl:if test="@id = 'chi'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<!-- the document title needs to be updated to reflect any changes to the patient hcn -->
							<xsl:if test="@id = 'hcn'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<!-- the document title needs to be updated to reflect any changes to the patient nhs number -->
							<xsl:if test="@id = 'patient_nhs_number'">
								<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
							</xsl:if>
							<xsl:if test="@width != ''">
								<xsl:attribute name="style">width:<xsl:value-of select="@width"/>px</xsl:attribute>
							</xsl:if>
							<xsl:if test="@onkeydown != ''">
								<xsl:attribute name="onkeydown"><xsl:value-of select="@onkeydown"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="normalize-space(@mandatory) = 'true'">
								<xsl:attribute name="class">mandText</xsl:attribute>
								<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="@readonly = 'true'">
								<xsl:attribute name="readonly">true</xsl:attribute>
							</xsl:if>
							<xsl:if test="@maxlength != ''">
								<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
							</xsl:if>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/></xsl:attribute>
						</xsl:element>
						<xsl:for-each select="./button">
							<xsl:call-template name="btnTemplate">
								<xsl:with-param name="id" select="@id"/>
								<xsl:with-param name="name" select="@name"/>
								<xsl:with-param name="onclick" select="@onclick"/>
								<xsl:with-param name="imgsrc" select="@src"/>
								<xsl:with-param name="value" select="@value"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="@type='hidden'">
						<xsl:element name="input">
							<xsl:attribute name="type">hidden</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/></xsl:attribute>
						</xsl:element>
					</xsl:when>
					<!-- Outputs a check box, using the standard question format. -->
					<xsl:when test="@type='check'">
						<xsl:element name="input">
							<xsl:attribute name="type">checkbox</xsl:attribute>
							<xsl:attribute name="style">width:16px</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
							<xsl:if test="@readonly = 'true'">
								<xsl:attribute name="readonly">true</xsl:attribute>
							</xsl:if>
							<xsl:if test="@hidden ='true'">
								<xsl:attribute name="style">display:none</xsl:attribute>
							</xsl:if>
							<xsl:if test="normalize-space(@mandatory) = 'true'">
								<xsl:attribute name="class">mandText</xsl:attribute>
								<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
							</xsl:if>
							<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
							<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
							<xsl:variable name="toconvert">
								<xsl:value-of select="@id"/>
							</xsl:variable>
							<xsl:variable name="protvalue">
								<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
							</xsl:variable>
							<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = 'true'">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
						</xsl:element>
					</xsl:when>
					<xsl:when test="@type='date' or @type='time'">
						<xsl:call-template name="dateinput">
							<xsl:with-param name="id" select="@id"/>
							<xsl:with-param name="userName" select="@userName"/>
							<xsl:with-param name="mandatory" select="@mandatory"/>
							<xsl:with-param name="isCell" select="'false'"/>
							<xsl:with-param name="readonly" select="@readonly"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='radio'">
						<table cellspacing="0" width="100%">
							<xsl:for-each select="option">
								<tr>
									<td align="left" width="16">
										<xsl:element name="input">
											<xsl:attribute name="type">radio</xsl:attribute>
											<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/></xsl:attribute>
											<xsl:attribute name="id"><xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="position()"/></xsl:attribute>
											<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
											<xsl:if test="@hidden ='true'">
												<xsl:attribute name="style">display:none</xsl:attribute>
											</xsl:if>
											<xsl:if test="parent::node()/attribute::onclick !=''">
												<xsl:attribute name="onclick"><xsl:value-of select="parent::node()/attribute::onclick"/></xsl:attribute>
											</xsl:if>
											<xsl:if test="@readonly = 'true'">
												<xsl:attribute name="readonly">true</xsl:attribute>
											</xsl:if>
											<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
											<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
											<xsl:variable name="toconvert">
												<xsl:value-of select="parent::node()/attribute::id"/>
											</xsl:variable>
											<xsl:variable name="protvalue">
												<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
											</xsl:variable>
											<xsl:choose>
												<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$protvalue]) &gt; 0">
													<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = @value">
														<xsl:attribute name="checked">true</xsl:attribute>
													</xsl:if>
												</xsl:when>
												<xsl:otherwise>
													<xsl:if test="@isDefault ='true'">
														<xsl:attribute name="checked">true</xsl:attribute>
													</xsl:if>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:if test="parent::node()/attribute::mandatory = 'true'">
												<xsl:attribute name="class">mandText</xsl:attribute>
												<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
											</xsl:if>
										</xsl:element>
									</td>
									<td width="*">&#160;&#160;<xsl:value-of select="@text"/>
									</td>
								</tr>
							</xsl:for-each>
						</table>
					</xsl:when>
					<xsl:when test="@type='select'">
						<table cellspacing="0">
							<tr>
								<td>
									<xsl:element name="select">
										<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
										<xsl:if test="normalize-space(@mandatory) = 'true'">
											<xsl:attribute name="class">mandText</xsl:attribute>
											<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
										</xsl:if>
										<xsl:if test="@hidden ='true'">
											<xsl:attribute name="style">display:none</xsl:attribute>
										</xsl:if>
										<xsl:for-each select="option">
											<xsl:element name="option">
												<xsl:attribute name="id"><xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="position()"/></xsl:attribute>
												<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
												<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
												<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
												<xsl:variable name="toconvert">
													<xsl:value-of select="parent::node()/attribute::id"/>
												</xsl:variable>
												<xsl:variable name="protvalue">
													<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
												</xsl:variable>
												<xsl:choose>
													<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$protvalue]) &gt; 0">
														<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = @value">
															<xsl:attribute name="selected">true</xsl:attribute>
														</xsl:if>
													</xsl:when>
													<xsl:otherwise>
														<xsl:if test="normalize-space(@isDefault)">
															<xsl:attribute name="selected">true</xsl:attribute>
														</xsl:if>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:value-of select="@text"/>
											</xsl:element>
										</xsl:for-each>
									</xsl:element>
								</td>
							</tr>
						</table>
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="readonly" select="@readonly"/>
		</xsl:call-template>
	</xsl:template>
	<!-- =========================================================
	 Name:			stdquestion
	 Description:	Outputs a standard question, with a caption, 
					input section and help text.
	 ========================================================= -->
	<xsl:template name="stdquestion">
		<xsl:param name="caption"/>
		<xsl:param name="help"/>
		<xsl:param name="mandatory"/>
		<xsl:param name="spellCheck"/>
		<xsl:param name="hidden"/>
		<xsl:param name="id"/>
		<xsl:param name="userinput"/>
		<xsl:param name="readonly"/>
		<table width="100%" cellspacing="0">
			<tr>
				<xsl:if test="normalize-space($caption)">
					<xsl:element name="td">
						<xsl:attribute name="class">question</xsl:attribute>
						<xsl:attribute name="id"><xsl:value-of select="$id"/>_caption</xsl:attribute>
						<xsl:if test="$hidden = 'true'">
							<xsl:attribute name="style">display:none</xsl:attribute>
						</xsl:if>
						<xsl:value-of select="$caption"/>
						<xsl:if test="normalize-space($mandatory) = 'true'">
							<xsl:text/>
							<b>*</b>
						</xsl:if>
					</xsl:element>
				</xsl:if>
				<td width="*" nowrap="true">
					<xsl:copy-of select="$userinput"/>
				</td>
				<td class="help">
					<xsl:if test="normalize-space($help)">
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
							<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpText(string($caption), string(normalize-space($help)))"/></xsl:attribute>
							<xsl:attribute name="class">hand</xsl:attribute>
							<xsl:attribute name="title">Click here for help</xsl:attribute>
							<xsl:if test="$hidden = 'true'">
								<xsl:attribute name="style">display:none</xsl:attribute>
							</xsl:if>
						</xsl:element>
					</xsl:if>
					<xsl:element name="input">
						<xsl:attribute name="type">hidden</xsl:attribute>
						<xsl:attribute name="name"><xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
					</xsl:element>
					<xsl:choose>
						<xsl:when test="$readonly = 'true'">
							<!-- Do not allow spell check on readonly text and textArea fields, even when prepopulation fails and fields are enabled -->
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="$enablespellcheck = 'true'">
								<xsl:if test="$spellCheck = 'true'">
									<img name="{$id}_img" onClick="SpellCheck({$id});" src="{$spellicon}" class="hand"/>
								</xsl:if>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!-- =========================================================
	 Name:			dateinput
	 Description:	Outputs our standard date input field.
	 ========================================================= -->
	<xsl:template name="dateinput">
		<xsl:param name="id"/>
		<xsl:param name="mandatory"/>
		<xsl:param name="userName"/>
		<xsl:param name="tableid"/>
		<xsl:param name="rowid"/>
		<xsl:param name="columnid"/>
		<xsl:param name="isCell"/>
		<xsl:param name="readonly"/>
		<!-- Output input field -->
		<xsl:element name="input">
			<xsl:attribute name="type">text</xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="$id"/></xsl:attribute>
			<xsl:if test="not($readonly = 'true')">
				<xsl:choose>
					<!-- If we are dealing with a patient DOB then we will need to format the date 
					     and update the document title to reflect the change -->
					<xsl:when test="@id = 'patient_dob'">
						<xsl:attribute name="onblur">DateOfBirthUnambiguousDateEntry(this);</xsl:attribute>
					</xsl:when>
					<!-- All other dates only have to be formatted -->
					<xsl:otherwise>
						<xsl:attribute name="onblur">UnambiguousDateEntry(this);</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="normalize-space($mandatory) = 'true'">
					<xsl:attribute name="class">mandDate</xsl:attribute>
					<xsl:attribute name="text"><xsl:value-of select="$userName"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">normalDate</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
			<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
			<xsl:variable name="toconvert">
				<xsl:value-of select="$id"/>
			</xsl:variable>
			<xsl:variable name="fldid">
				<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$isCell = 'true'">
					<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$fldid]/attribute::value"/></xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="$readonly = 'true'">
				<xsl:attribute name="readonly">true</xsl:attribute>
			</xsl:if>
		</xsl:element>
		<!-- Spacer -->
		<xsl:text/>
		<!-- Output datepicker button -->
		<xsl:choose>
			<xsl:when test="$readonly = 'true'">
				<!-- Do not display any image -->
			</xsl:when>
			<xsl:otherwise>
				<img name="{$id}_img" onClick="ShowCalendar({$id}, {$id});" src="{$dateicon}" class="hand"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- =========================================================
	 Name:			category\question[@type='textArea'  or @type='text' or @type='hidden' or @type='check' or @type='date' or @type='radio' or @type='select' or type='time']
	 Description:	writes input controls based on the type of questions in the protocol
	 ========================================================= -->
	<xsl:template match="question[@type='textArea'  or @type='text' or @type='hidden' or @type='check' or @type='date' or @type='radio' or @type='select' or @type='time']">
		<xsl:if test="$isrequestinghcp='true'">
			<xsl:choose>
				<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestinghcp_')='true')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
				<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestingorg_')='true')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
				<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestinggp_')='true')">
						
					</xsl:when>
				<xsl:when test=" (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and ($showgpquestions = 'true')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
				<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and  ($showgpquestions = 'false')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
				<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and  ($showgpquestions = 'false')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="$isrequestinghcp='false'">
			<xsl:choose>
				<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestinghcp_')='true')">
					
				</xsl:when>
				<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestingorg_')='true')">
					
				</xsl:when>
				<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestinggp_')='true')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
				<xsl:when test=" (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and ($showgpquestions = 'true')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
				<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and  ($showgpquestions = 'false')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
				<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and  ($showgpquestions = 'false')">
					<xsl:call-template name="genericQuestion"/>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	<!-- =========================================================
	 Name:			category\question[type='table']
	 Description:	Displays, populates and gives a unique ID to questions
					that are output as rows of a table.
	 ========================================================= -->
	<xsl:template match="question[@type='table']">
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="tableid">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<div>
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name"><xsl:value-of select="@id"/>_rowCount</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="count(row)"/></xsl:attribute>
			</xsl:element>
			<table cellspacing="0" width="100%" id="{@id}">
				<!-- Output columns - the first is the heading caption -->
				<th>
					<font class="tableCaption">
						<xsl:value-of select="@text"/>
					</font>
				</th>
				<xsl:for-each select="column">
					<xsl:element name="th">
						<xsl:attribute name="valign">bottom</xsl:attribute>
						<xsl:call-template name="addHiddenCellClass"/>
						<xsl:value-of select="@text"/>
						<xsl:element name="input">
							<xsl:attribute name="type">hidden</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/>___<xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
						</xsl:element>
					</xsl:element>
					<xsl:element name="th">
						<xsl:call-template name="addHiddenCellClass"/>
						<xsl:choose>
							<xsl:when test="@spellCheck = 'true'">
								<xsl:if test="$enablespellcheck = 'true'">
									<xsl:element name="img">
										<xsl:attribute name="src"><xsl:value-of select="$spellicon"/></xsl:attribute>
										<xsl:attribute name="class">hand</xsl:attribute>
										<xsl:attribute name="align">right</xsl:attribute>
										<xsl:attribute name="onClick">SpellCheckColumn("<xsl:value-of select="$tableid"/>", "<xsl:value-of select="@id"/>")</xsl:attribute>
									</xsl:element>
								</xsl:if>
							</xsl:when>
						</xsl:choose>
					</xsl:element>
				</xsl:for-each>
				<th>
					<xsl:element name="input">
						<xsl:attribute name="type">hidden</xsl:attribute>
						<xsl:attribute name="name"><xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
					</xsl:element>
				</th>
				<xsl:for-each select="row">
					<xsl:variable name="row_num">
						<xsl:value-of select="position()"/>
					</xsl:variable>
					<xsl:variable name="row_id">
						<xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="$row_num"/>
					</xsl:variable>
					<tr>
						<td class="question">
							<xsl:value-of select="@text"/>
							<xsl:element name="input">
								<xsl:attribute name="type">hidden</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$row_id"/>_hiddenName</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
							</xsl:element>
						</td>
						<xsl:for-each select="parent::node()/child::column">
							<xsl:variable name="cell_id">
								<xsl:value-of select="parent::node()/attribute::id"/>___<xsl:value-of select="@id"/>_<xsl:value-of select="$row_num"/>
							</xsl:variable>
							<xsl:choose>
								<!-- Output a date cell -->
								<xsl:when test="normalize-space(@type)='date'">
									<xsl:element name="td">
										<xsl:attribute name="nowrap">true</xsl:attribute>
										<xsl:attribute name="width">113</xsl:attribute>
										<xsl:call-template name="addHiddenCellClass"/>
										<xsl:call-template name="dateinput">
											<xsl:with-param name="id" select="$cell_id"/>
											<xsl:with-param name="tableid" select="$tableid"/>
											<xsl:with-param name="rowid" select="$row_num"/>
											<xsl:with-param name="columnid" select="@id"/>
											<xsl:with-param name="isCell" select="'true'"/>
											<xsl:with-param name="readonly" select="(@readonly[.='true']/. | @hidden[.='true']/.)[1]"/>
										</xsl:call-template>
									</xsl:element>
								</xsl:when>
								<!-- Output a select cell -->
								<xsl:when test="@type='select'">
									<xsl:element name="td">
										<xsl:attribute name="width">0</xsl:attribute>
										<xsl:call-template name="addHiddenCellClass"/>
										<xsl:element name="select">
											<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
											<xsl:if test="@hidden = 'true'">
												<xsl:attribute name="disabled">disabled</xsl:attribute>
											</xsl:if>
											<xsl:for-each select="option">
												<xsl:element name="option">
													<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
													<xsl:variable name="columnid" select="parent::node()/@id"/>
													<xsl:choose>
														<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]) &gt; 0">
															<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]/attribute::value = @value">
																<xsl:attribute name="selected">true</xsl:attribute>
															</xsl:if>
														</xsl:when>
														<xsl:otherwise>
															<xsl:if test="normalize-space(@isDefault)">
																<xsl:attribute name="selected">true</xsl:attribute>
															</xsl:if>
														</xsl:otherwise>
													</xsl:choose>
													<xsl:value-of select="@text"/>
												</xsl:element>
											</xsl:for-each>
										</xsl:element>
									</xsl:element>
								</xsl:when>
								<!-- Output a standard text cell -->
								<xsl:otherwise>
									<xsl:element name="td">
										<xsl:attribute name="width">*</xsl:attribute>
										<!-- colspan to fit spell check icon -->
										<xsl:attribute name="colspan">2</xsl:attribute>
										<xsl:call-template name="addHiddenCellClass"/>
										<xsl:element name="input">
											<xsl:attribute name="type">text</xsl:attribute>
											<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
											<xsl:variable name="columnid" select="@id"/>
											<xsl:if test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]) &gt; 0">
												<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$row_num]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
											</xsl:if>
											<xsl:if test="@maxlength != ''">
												<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
											</xsl:if>
											<xsl:if test="normalize-space(@mandatory) = 'true'">
												<xsl:attribute name="class">mandText</xsl:attribute>
												<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
											</xsl:if>
											<xsl:if test="@hidden = 'true'">
												<xsl:attribute name="readonly">readonly</xsl:attribute>
											</xsl:if>
											<xsl:if test="@property='BnfCode' or @property='Code' or @property='CodeScheme' or @property='CodeSchemeVersion' or @propertyOld='BNFCode' or @propertyOld='ReadCode' or @propertyOld='CodeScheme' or @propertyOld='CodeSchemeVersion'">
												<!-- this test is to ensure read code fields are always read only -->
												<xsl:attribute name="readonly">readonly</xsl:attribute>
											</xsl:if>
										</xsl:element>
									</xsl:element>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<td class="help">
							<xsl:if test="normalize-space(@help)">
								<xsl:element name="img">
									<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
									<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpText(string(@text), string(normalize-space(@help)))"/></xsl:attribute>
									<xsl:attribute name="class">hand</xsl:attribute>
									<xsl:attribute name="title">Click here for help</xsl:attribute>
								</xsl:element>
							</xsl:if>
						</td>
					</tr>
				</xsl:for-each>
				<!-- row -->
			</table>
		</div>
	</xsl:template>
	<!-- =========================================================
	 Name:			category\question[type='dynaTable']
	 Description:	Displays, populates and gives a unique ID to questions
					that are output as a dynamic table.
	 ========================================================= -->
	<xsl:template match="question[@type='dynaTable' or @type='giDynaTable']">
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="tableid">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<p>
			<table width="98%" cellspacing="0">
				<!-- <tr height="5"><td colspan="3"></td></tr> -->
				<tr>
					<td width="*" align="left">
						<font class="tableCaption">
							<xsl:value-of select="@text"/>
						</font>
					</td>
					<xsl:element name="td">
						<xsl:attribute name="align">center</xsl:attribute>
						<xsl:attribute name="class">buttonup</xsl:attribute>
						<xsl:attribute name="style">width:80;display:none;</xsl:attribute>
						<xsl:attribute name="onClick">ShowHideDeletedRows("<xsl:value-of select="@id"/>")</xsl:attribute>
						<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
						<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
						<xsl:attribute name="title">Click here to hide deleted rows</xsl:attribute>
						<xsl:attribute name="id">showHideDeleted_<xsl:value-of select="@id"/></xsl:attribute>Hide Deleted Rows</xsl:element>
					<xsl:element name="td">
						<xsl:attribute name="align">center</xsl:attribute>
						<xsl:attribute name="class">buttonup</xsl:attribute>
						<xsl:attribute name="style">width:80;</xsl:attribute>
						<xsl:attribute name="onClick">addRow("<xsl:value-of select="@id"/>")</xsl:attribute>
						<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
						<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
						<xsl:attribute name="title">Click here to add a new row</xsl:attribute>
						<xsl:attribute name="id">addRow_<xsl:value-of select="@id"/></xsl:attribute>Add Row</xsl:element>
					<td class="help">
						<xsl:if test="normalize-space(@help)">
							<xsl:element name="img">
								<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
								<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpText(string(@text), string(normalize-space(@help)))"/></xsl:attribute>
								<xsl:attribute name="class">hand</xsl:attribute>
								<xsl:attribute name="title">Click here for help</xsl:attribute>
							</xsl:element>
						</xsl:if>
					</td>
				</tr>
			</table>
			<div align="left" class="dynaTable">
				<xsl:element name="input">
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@id"/>_rowCount</xsl:attribute>
					<xsl:choose>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) = 0">
							<xsl:attribute name="value">1</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="value"><xsl:value-of select="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row)"/></xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<table cellspacing="2" width="100%" id="{@id}">
					<tr>
						<xsl:element name="th">
							<!-- Column header for row's delete button -->
						</xsl:element>
						<!-- Note that we do not output a heading caption for table questions -->
						<!-- Output columns - the first and last are blank -->
						<xsl:for-each select="column">
							<xsl:element name="th">
								<xsl:call-template name="addHiddenCellClass"/>
								<xsl:value-of select="@text"/>
								<xsl:element name="input">
									<xsl:attribute name="type">hidden</xsl:attribute>
									<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/>___<xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
									<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
								</xsl:element>
								<xsl:if test="@spellCheck='true'">
									<xsl:if test="$enablespellcheck = 'true'">
										<xsl:element name="img">
											<xsl:attribute name="src"><xsl:value-of select="$spellicon"/></xsl:attribute>
											<xsl:attribute name="class">hand</xsl:attribute>
											<xsl:attribute name="align">right</xsl:attribute>
											<xsl:attribute name="onClick">SpellCheckColumn("<xsl:value-of select="$tableid"/>", "<xsl:value-of select="@id"/>")</xsl:attribute>
										</xsl:element>
									</xsl:if>
								</xsl:if>
							</xsl:element>
						</xsl:for-each>
						<th>
							<xsl:element name="input">
								<xsl:attribute name="type">hidden</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
							</xsl:element>
						</th>
					</tr>
					<!-- write the rows out.  -->
					<xsl:variable name="orgtableid">
						<xsl:value-of select="@id"/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]) = 0">
							<xsl:call-template name="dynaTableRow">
								<xsl:with-param name="tableid" select="$tableid"/>
								<xsl:with-param name="orgtableid" select="$orgtableid"/>
								<xsl:with-param name="rowid" select="1"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]) &gt; 0">
							<xsl:choose>
								<!-- Create as many rows as there are rows in the data xml-->
								<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) &gt; 0">
									<xsl:for-each select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row">
										<xsl:call-template name="dynaTableRow">
											<xsl:with-param name="tableid" select="$tableid"/>
											<xsl:with-param name="orgtableid" select="$orgtableid"/>
											<xsl:with-param name="rowid" select="@id"/>
										</xsl:call-template>
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) &lt; 1">
									<xsl:call-template name="dynaTableRow">
										<xsl:with-param name="tableid" select="$tableid"/>
										<xsl:with-param name="orgtableid" select="$orgtableid"/>
										<xsl:with-param name="rowid" select="1"/>
									</xsl:call-template>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</table>
				<br/>
			</div>
		</p>
	</xsl:template>
	<!-- =========================================================
	 Name:			dynaTableRow
	 Description:	Outputs a row for a dynatable
	 ========================================================= -->
	<xsl:template name="dynaTableRow">
		<xsl:param name="tableid"/>
		<xsl:param name="orgtableid"/>
		<xsl:param name="rowid"/>
		<tr id="{$tableid}_{$rowid}">
			<!-- writes the delete row button-->
			<xsl:element name="td">
				<xsl:attribute name="align">right</xsl:attribute>
				<xsl:variable name="cell_id">
					<xsl:value-of select="$tableid"/>___<xsl:value-of select="@id"/>_<xsl:value-of select="$rowid"/>
				</xsl:variable>
				<xsl:attribute name="id">delRow_<xsl:value-of select="$cell_id"/></xsl:attribute>
				<xsl:attribute name="onClick">deleteRow(this, "<xsl:value-of select="$tableid"/>")</xsl:attribute>
				<xsl:attribute name="title">Click here to delete this row</xsl:attribute>
				<xsl:attribute name="style">width:15px;height:15px;background-color:#C0C0C0;</xsl:attribute>
				<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
				<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
				<xsl:attribute name="class">buttonup</xsl:attribute>
				<xsl:element name="img">
					<xsl:attribute name="style">width:15px;height:15px;</xsl:attribute>
					<xsl:attribute name="src"><xsl:value-of select="$deleteicon"/></xsl:attribute>
				</xsl:element>
			</xsl:element>
			<xsl:for-each select="//question[@id=$orgtableid]/column">
				<xsl:variable name="cell_id">
					<xsl:value-of select="$orgtableid"/>___<xsl:value-of select="@id"/>_<xsl:value-of select="$rowid"/>
				</xsl:variable>
				<xsl:variable name="radio_id">
					<xsl:value-of select="$orgtableid"/>___<xsl:value-of select="@id"/>
				</xsl:variable>
				<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
				<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
				<xsl:variable name="toconvert">
					<xsl:value-of select="@id"/>
				</xsl:variable>
				<xsl:variable name="columnid">
					<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="@type='date' or @type='time'">
						<xsl:element name="td">
							<xsl:attribute name="nowrap">true</xsl:attribute>
							<xsl:attribute name="width">113</xsl:attribute>
							<xsl:call-template name="addHiddenCellClass"/>
							<xsl:element name="input">
								<xsl:attribute name="type">text</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
								<xsl:attribute name="class">normalDate</xsl:attribute>
								<xsl:if test="not(@hidden = 'true')">
									<xsl:choose>
										<!-- If we are dealing with a patient DOB then we will need to format the 
											 date and update the document title to reflect the change -->
										<xsl:when test="@id = 'patient_dob'">
											<xsl:attribute name="onblur">DateOfBirthUnambiguousDateEntry(this);</xsl:attribute>
										</xsl:when>
										<!-- All other dates only have to be formatted -->
										<xsl:otherwise>
											<xsl:attribute name="onblur">UnambiguousDateEntry(this);</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
								<xsl:if test="normalize-space(@mandatory) = 'true'">
									<xsl:attribute name="class">mandDate</xsl:attribute>
									<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
								</xsl:if>
								<xsl:choose>
									<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
										<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="value"/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:if test="@hidden = 'true'">
									<xsl:attribute name="readonly">readonly</xsl:attribute>
								</xsl:if>
							</xsl:element>
							<xsl:text/>
							<xsl:if test="not(@hidden = 'true')">
								<xsl:element name="img">
									<xsl:attribute name="name"><xsl:value-of select="$cell_id"/>_img</xsl:attribute>
									<xsl:attribute name="onclick"><![CDATA[ShowCalendar(]]><xsl:value-of select="$cell_id"/><![CDATA[,]]><xsl:value-of select="$cell_id"/><![CDATA[);]]></xsl:attribute>
									<xsl:attribute name="src"><xsl:value-of select="$dateicon"/></xsl:attribute>
									<xsl:attribute name="class">hand</xsl:attribute>
								</xsl:element>
							</xsl:if>
						</xsl:element>
					</xsl:when>
					<xsl:when test="@type='select'">
						<xsl:element name="td">
							<xsl:call-template name="addHiddenCellClass"/>
							<xsl:element name="select">
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
								<xsl:if test="normalize-space(@mandatory) = 'true'">
									<xsl:attribute name="class">mandText</xsl:attribute>
								</xsl:if>
								<xsl:if test="@hidden = 'true'">
									<xsl:attribute name="disabled">disabled</xsl:attribute>
								</xsl:if>
								<xsl:for-each select="option">
									<xsl:element name="option">
										<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
										<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
										<xsl:choose>
											<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
												<xsl:choose>
													<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value = @value">
														<xsl:attribute name="selected">true</xsl:attribute>
													</xsl:when>
													<xsl:otherwise>
														<xsl:if test="normalize-space(@isDefault)">
															<xsl:attribute name="selected">true</xsl:attribute>
														</xsl:if>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:when>
											<xsl:otherwise>
												<xsl:if test="normalize-space(@isDefault)">
													<xsl:attribute name="selected">true</xsl:attribute>
												</xsl:if>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:value-of select="@text"/>
									</xsl:element>
								</xsl:for-each>
							</xsl:element>
						</xsl:element>
					</xsl:when>
					<xsl:when test="@type='radio'">
						<xsl:element name="td">
							<xsl:attribute name="width">*</xsl:attribute>
							<xsl:call-template name="addHiddenCellClass"/>
							<table cellspacing="0" width="100%">
								<xsl:for-each select="option">
									<tr>
										<td align="left" width="16">
											<xsl:element name="input">
												<xsl:attribute name="type">radio</xsl:attribute>
												<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
												<xsl:attribute name="id"><xsl:value-of select="$radio_id"/>_<xsl:value-of select="position()"/>_<xsl:value-of select="$rowid"/></xsl:attribute>
												<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
												<xsl:if test="@hidden ='true'">
													<xsl:attribute name="style">display:none</xsl:attribute>
												</xsl:if>
												<xsl:if test="parent::node()/attribute::onclick !=''">
													<xsl:attribute name="onclick"><xsl:value-of select="parent::node()/attribute::onclick"/></xsl:attribute>
												</xsl:if>
												<xsl:if test="@readonly = 'true'">
													<xsl:attribute name="readonly">true</xsl:attribute>
												</xsl:if>
												<xsl:choose>
													<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
														<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value = @value">
															<xsl:attribute name="checked">true</xsl:attribute>
														</xsl:if>
													</xsl:when>
													<xsl:otherwise>
														<xsl:if test="@isDefault ='true'">
															<xsl:attribute name="checked">true</xsl:attribute>
														</xsl:if>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:if test="parent::node()/attribute::mandatory = 'true'">
													<xsl:attribute name="class">mandText</xsl:attribute>
													<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
												</xsl:if>
											</xsl:element>
										</td>
										<td width="*">&#160;&#160;<xsl:value-of select="@text"/>
										</td>
									</tr>
								</xsl:for-each>
							</table>
						</xsl:element>
					</xsl:when>
					<xsl:when test="@type='textArea'">
						<xsl:element name="td">
							<xsl:attribute name="width">*</xsl:attribute>
							<xsl:call-template name="addHiddenCellClass"/>
							<xsl:element name="textArea">
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
								<xsl:if test="@maxlength != ''">
									<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="normalize-space(@mandatory) = 'true'">
									<xsl:attribute name="class">mandText</xsl:attribute>
									<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="@property='BnfCode' or @property='Code' or @property='CodeScheme' or @property='CodeSchemeVersion' or @propertyOld='BNFCode' or @propertyOld='ReadCode' or @propertyOld='CodeScheme' or @propertyOld='CodeSchemeVersion'">
									<!-- this test is to ensure read code fields are always read only -->
									<xsl:attribute name="readonly">readonly</xsl:attribute>
								</xsl:if>
								<xsl:if test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
									<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value"/>
								</xsl:if>
							</xsl:element>
						</xsl:element>
					</xsl:when>
					<xsl:when test="@type='text' or not(@type)">
						<xsl:element name="td">
							<xsl:attribute name="width">*</xsl:attribute>
							<xsl:call-template name="addHiddenCellClass"/>
							<!-- colspan to fit spell check icon -->
							<xsl:element name="input">
								<xsl:attribute name="type">text</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="$cell_id"/></xsl:attribute>
								<xsl:if test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]) &gt; 0">
									<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row[@id=$rowid]/column[@id=$columnid]/attribute::value"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="@maxlength != ''">
									<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="normalize-space(@mandatory) = 'true'">
									<xsl:attribute name="class">mandText</xsl:attribute>
									<xsl:attribute name="text"><xsl:value-of select="@userName"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="@hidden = 'true'">
									<xsl:attribute name="readonly">readonly</xsl:attribute>
								</xsl:if>
								<xsl:if test="@property='BnfCode' or @property='Code' or @property='CodeScheme' or @property='CodeSchemeVersion' or @propertyOld='BNFCode' or @propertyOld='ReadCode' or @propertyOld='CodeScheme' or @propertyOld='CodeSchemeVersion'">
									<!-- this test is to ensure read code fields are always read only -->
									<xsl:attribute name="readonly">readonly</xsl:attribute>
								</xsl:if>
							</xsl:element>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="td">
							<xsl:attribute name="width">*</xsl:attribute>
							<xsl:call-template name="addHiddenCellClass"/>
							Unknown type <xsl:value-of select="@type"/>!!
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<td class="help"/>
		</tr>
	</xsl:template>
	<!-- ===========================================================
	Name:			button
	Description:		writes any button specified for a question next to the control
	=========================================================== -->
	<xsl:template name="btnTemplate">
		<xsl:param name="id"/>
		<xsl:param name="name"/>
		<xsl:param name="onclick"/>
		<xsl:param name="imgsrc"/>
		<xsl:param name="value"/>
		<xsl:element name="button">
			<xsl:attribute name="id"><xsl:value-of select="$id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
			<xsl:attribute name="onclick"><xsl:value-of select="$onclick"/></xsl:attribute>
			<xsl:choose>
				<xsl:when test="$imgsrc != ''">
					<xsl:element name="img">
						<xsl:attribute name="src"><xsl:value-of select="$imgsrc"/></xsl:attribute>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<xsl:template match="hdnflds">
		<xsl:element name="form">
			<xsl:attribute name="id">protocolInfo</xsl:attribute>
			<xsl:attribute name="name">protocolInfo</xsl:attribute>
			<xsl:for-each select="hdnfld">
				<xsl:element name="input">
					<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<!-- 
===============================================================================================
	Name:			control
	Description:		sets up the dropdowns and clientside events for the referrer and registrar controls
	================================================================================================ -->
	<xsl:template match="control">
		<xsl:call-template name="referrerOrRegistrarControl"/>
	</xsl:template>
	<!--
==================================================================================================
==================================================================================================
I N T E R A C T I V E      F O R M S      S T Y L E S H E E T / T E M P L A T E S
==================================================================================================
==================================================================================================
-->
	<xsl:template name="gwInternalProtocolV2">
		<!-- Date picker -->
		<script language="javascript">
		
		// Function to display the date-picker calendar to the user	 
		function ShowCalendar(objTakeDateFrom, objSetDateOn)
		{
			// Make the calendar container visible
			popupContainer.style.display = "inline";

			// Open the javascript calendar and give it focus
			popFrame.fPopCalendar(objTakeDateFrom, objSetDateOn, popupContainer);
			popupContainer.firstChild.focus();
			
			// Attach handler for clicks outside the iframe
			popupContainer.firstChild.onblur = HideCalender;
		}
		
		// Handler for when the calendar iframe is deselected
		function HideCalender()
		{	
			// Make calendar invisible
			popupContainer.style.display = "none";
		}
		
	</script>
		<!-- Spell checker -->
		<script language="javascript">
		
		 // Function to display the spell check dialog to the user - text areas
		function SpellCheck(objTextControl)
		{
		RunSpellCheck(objTextControl);
		}

		 // Function to display the spell check dialog to the user	 
		function SpellCheckColumn(sTableId, sColumnId)
		{
		RunSpellCheckColumn(sTableId, sColumnId);
		}
		
	</script>
		<div id="popupContainer" style="display:none; position:absolute; Z-INDEX: 101;">
			<iframe name="popFrame" src="{$calendar}" style="height:190px; width:180px;"/>
		</div>
		<!-- Tab Bar -->
		<div class="tabBar">
			<table cellspacing="0" cellpadding="0">
				<tr height="17">
					<!-- Output tabs -->
					<xsl:apply-templates select="./category" mode="tabV2"/>
					<td width="100%"/>
				</tr>
			</table>
			<span id="tabBar"/>
			<table cellspacing="0" width="100%">
				<tr>
					<td height="1px" bgcolor="black"/>
				</tr>
				<tr>
					<td class="protocolTitle">
						<xsl:value-of select="@name"/> (v<xsl:value-of select="@version"/>)</td>
				</tr>
			</table>
		</div>
		<!-- Referral data-entry form placeholder -->
		<form name="formRef" method="post">
			<!-- Hidden fields for protocol name, region, and version -->
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name">protocol_name</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@name"/></xsl:attribute>
			</xsl:element>
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name">protocol_region</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@region"/></xsl:attribute>
			</xsl:element>
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="name">protocol_version</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@version"/></xsl:attribute>
			</xsl:element>
			<!-- Holder for tab index -->
			<input type="hidden" id="tabIndexStore" value="divTabControl_1"/>
			<!-- Transform category elements -->
			<xsl:apply-templates select="./category" mode="pageV2"/>
		</form>
		<xsl:apply-templates select="/gwInternalProtocol/messagexml/prtobjcts/hdnflds"/>
		<xsl:call-template name="IAFormsScriptBuilder"/>
	</xsl:template>
	<!-- =========================================================
	 Name:			\protocol\category
	 Description:	Categories within the protocol. The category represents the highest level of division within the protocol definition. For page categories
					output tab flags, and then recurse down, outputting a heading, then free text, questions, and sub-categories. 
	 ========================================================= -->
	<!-- Output tabs for page level categories =========================== -->
	<xsl:template match="category" mode="tabV2">
		<td>
			<img src="{$spacer}" width="1"/>
		</td>
		<xsl:element name="td">
			<xsl:attribute name="class">tab</xsl:attribute>
			<xsl:attribute name="id">tab_<xsl:value-of select="position()"/></xsl:attribute>
			<xsl:attribute name="nowrap">true</xsl:attribute>
			<xsl:attribute name="onclick">goTab(<xsl:value-of select="position()"/>)</xsl:attribute>
			<!-- Highlight the first tab -->
			<xsl:if test="position()=1">
				<xsl:attribute name="style">color:white;background-color:#000066;</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="@text"/>
		</xsl:element>
	</xsl:template>
	<!-- Output elements for page level categories ======================== -->
	<xsl:template match="category" mode="pageV2">
		<xsl:element name="div">
			<xsl:attribute name="class">categoryContent</xsl:attribute>
			<xsl:attribute name="id">divTabControl_<xsl:value-of select="position()"/></xsl:attribute>
			<!-- Make the first tab visible -->
			<xsl:if test="position()=1">
				<xsl:attribute name="style">visibility:visible;display: block;</xsl:attribute>
			</xsl:if>
			<xsl:if test="position()>1">
				<xsl:attribute name="style">visibility:hidden;display: none;</xsl:attribute>
			</xsl:if>
			<!-- Add hidden tab flag -->
			<xsl:element name="input">
				<xsl:attribute name="type">hidden</xsl:attribute>
				<xsl:attribute name="id">tabName_<xsl:value-of select="@text"/></xsl:attribute>
				<xsl:attribute name="name"><xsl:value-of select="@text"/></xsl:attribute>
			</xsl:element>
			<!-- Apply standard category processing -->
			<xsl:apply-templates select="." mode="V2">
				<xsl:with-param name="level" select="1"/>
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>
	<!-- Process normal category elements ==================================== -->
	<xsl:template match="category" mode="V2">
		<xsl:param name="level" select="3"/>
		<!-- Select the heading to output based on the level -->
		<xsl:choose>
			<xsl:when test="$level &gt;= 3">
				<!-- anything lower than 3 defaults to <h3> -->
				<xsl:element name="h3">
					<xsl:value-of select="@text"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="h{$level}">
					<xsl:value-of select="@text"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
		<!-- Apply templates for elements found within categories -->
		<xsl:apply-templates select="./question | ./h1 | ./h2 | ./h3 | ./p | ./i | ./b | ./u | ./span | ./control | ./ol | ./ul | ./table | ./a | ./div" mode="V2"/>
	</xsl:template>
	<xsl:template match="h1 | h2 | h3 | div | p | i | b | u | span | ol | ul | li | table | tr | td | a | text()" mode="V2">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()" mode="V2"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="a" mode="V2">
		<xsl:element name="a">
			<xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
			<xsl:if test="@id">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@target">
				<xsl:attribute name="target"><xsl:value-of select="@target"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@targetID">
				<xsl:attribute name="onClick">goToObject('<xsl:value-of select="@targetID"/>', '', '');</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<!-- =========================================================
	 Name:			question[@type='textArea'  or @type='text' or @type='hidden' or @type='check' or @type='date' or @type='radio' 
						or @type='select' or type='time']

	 Description:	Filters the referring/requesting gp and hcp questions to display the correct ones based on $showgpquestions and
						$isrequestinghcp. Calls genericQuestionV2 template to output the question
	 ========================================================= -->
	<xsl:template match="question[@type='textArea'  or @type='text' or @type='hidden' or @type='check' or @type='date' or @type='radio' or @type='select' or @type='time']" mode="V2">
		<xsl:choose>
			<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestinggp_')='true')">
				<xsl:choose>
					<xsl:when test="($isrequestinghcp='true')"/>
					<xsl:otherwise>
						<xsl:call-template name="genericQuestionV2"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestinghcp_')='true')">
				<xsl:choose>
					<xsl:when test="($isrequestinghcp='true')">
						<xsl:call-template name="genericQuestionV2"/>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'requestingorg_')='true')">
				<xsl:choose>
					<xsl:when test="($isrequestinghcp='true')">
						<xsl:call-template name="genericQuestionV2"/>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:when>
			<xsl:when test=" (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and (starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and ($showgpquestions = 'true')">
				<xsl:call-template name="genericQuestionV2"/>
			</xsl:when>
			<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and  ($showgpquestions = 'false')">
				<xsl:call-template name="genericQuestionV2"/>
			</xsl:when>
			<xsl:when test=" ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refgp_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'reforg_')!='true') and ( starts-with(translate(@id,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'refhcp_')!='true') and  ($showgpquestions = 'false')">
				<xsl:call-template name="genericQuestionV2"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- =========================================================
	 Name:			genericQuestionV2

	 Description:	Output a generic question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="genericQuestionV2">
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="lcId">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<xsl:variable name="dispClass">
			<xsl:choose>
				<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::display!=''">
					<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::display"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="@display">
							<xsl:value-of select="@display"/>
						</xsl:when>
						<xsl:otherwise>displayed</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="visClass">
			<xsl:choose>
				<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::visibility!=''">
					<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::visibility"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="@visible">
							<xsl:value-of select="@visible"/>
						</xsl:when>
						<xsl:otherwise>visible</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="reqdClass">
			<xsl:choose>
				<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::required!=''">
					<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::required"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="@mandatory='true'">required</xsl:when>
						<xsl:otherwise>optional</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="enbldClass">
			<xsl:choose>
				<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::enabled!=''">
					<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$lcId]/attribute::enabled"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="@enabled">
							<xsl:value-of select="@enabled"/>
						</xsl:when>
						<xsl:otherwise>enabled</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:call-template name="standardQuestionV2">
			<xsl:with-param name="caption" select="@text"/>
			<xsl:with-param name="help" select="help"/>
			<xsl:with-param name="mandatory" select="@mandatory"/>
			<xsl:with-param name="spellCheck" select="@spellCheck"/>
			<xsl:with-param name="hidden">
				<xsl:choose>
					<!-- Outputs a multi-line text box -->
					<xsl:when test="@type='hidden'">
						<xsl:value-of select="'true'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@hidden"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="id" select="@id"/>
			<xsl:with-param name="userinput">
				<xsl:choose>
					<xsl:when test="@type='text'">
						<xsl:call-template name="textInputV2">
							<xsl:with-param name="reqdClass" select="$reqdClass"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='textArea'">
						<xsl:call-template name="textAreaInputV2">
							<xsl:with-param name="reqdClass" select="$reqdClass"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='date'">
						<xsl:call-template name="dateInputV2">
							<xsl:with-param name="reqdClass" select="$reqdClass"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='check'">
						<xsl:call-template name="checkBoxInputV2">
							<xsl:with-param name="reqdClass" select="$reqdClass"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='radio'">
						<xsl:call-template name="radioButtonInputV2">
							<xsl:with-param name="reqdClass" select="$reqdClass"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='select'">
						<xsl:call-template name="dropDownInputV2">
							<xsl:with-param name="reqdClass" select="$reqdClass"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="@type='hidden'">
						<xsl:call-template name="hiddenInputV2">
							<xsl:with-param name="reqdClass" select="$reqdClass"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="readonly" select="@readonly"/>
			<xsl:with-param name="dispClass" select="$dispClass"/>
			<xsl:with-param name="visClass" select="$visClass"/>
			<xsl:with-param name="enbldClass" select="$enbldClass"/>
		</xsl:call-template>
	</xsl:template>
	<!-- =========================================================
	 Name:			standardQuestionV2
	 Description:	Outputs a standard question, with a caption, 
					input section and help text in V2 protocol output format, i.e. using divs
	 ========================================================= -->
	<xsl:template name="standardQuestionV2">
		<xsl:param name="caption"/>
		<xsl:param name="help"/>
		<xsl:param name="mandatory"/>
		<xsl:param name="spellCheck"/>
		<xsl:param name="hidden"/>
		<xsl:param name="id"/>
		<xsl:param name="userinput"/>
		<xsl:param name="readonly"/>
		<xsl:param name="dispClass"/>
		<xsl:param name="visClass"/>
		<xsl:param name="enbldClass"/>
		<xsl:variable name="contentClass">divQC,<xsl:value-of select="$dispClass"/>,<xsl:value-of select="$visClass"/>,<xsl:value-of select="$enbldClass"/>
		</xsl:variable>
		<xsl:variable name="fixedWidth">
			<xsl:choose>
				<xsl:when test="@width !='' or @type='date' or @type='radio' or @type='select' or @type='check'">true</xsl:when>
				<xsl:otherwise>false</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:element name="div">
			<xsl:attribute name="id">divQC_<xsl:value-of select="$id"/></xsl:attribute>
			<xsl:attribute name="class" xml:space="preserve"><xsl:value-of select="translate($contentClass, ',', ' ')"/></xsl:attribute>
			<xsl:if test="$caption!=''">
				<xsl:element name="div">
					<xsl:attribute name="class">divQCCaption <xsl:choose><xsl:when test="@textLocation='above'"></xsl:when><xsl:otherwise><xsl:text> floatLeft</xsl:text></xsl:otherwise></xsl:choose></xsl:attribute>
					<xsl:element name="label">
						<xsl:attribute name="for"><xsl:value-of select="$id"/></xsl:attribute>
						<xsl:value-of select="$caption"/>
						<xsl:if test="$mandatory='true'">
							<b>*</b>
						</xsl:if>
					</xsl:element>
				</xsl:element>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="$fixedWidth = 'true'">
					<!-- Fixed width layout -->
					<div class="divQCQuestion">
						<xsl:copy-of select="$userinput"/>
					</div>
					<div class="divQCFixedWidthIcons">
						<xsl:if test="$enablespellcheck = 'true'">
							<xsl:if test="$spellCheck = 'true'">
								<img id="{$id}_spellCheck" name="{$id}_img" onClick="if (IAForms.isAccessible('{$id}')) SpellCheck({$id});" src="{$spellicon}" class="hand"/>
							</xsl:if>
						</xsl:if>
						<xsl:if test="normalize-space($help)">
							<xsl:element name="img">
								<xsl:attribute name="id"><xsl:value-of select="$id"/>_helpIcon</xsl:attribute>
								<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
								<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpTextIfAccessible(string($caption), string(normalize-space($help)), string($id))"/></xsl:attribute>
								<xsl:attribute name="class">hand</xsl:attribute>
								<xsl:attribute name="title">Click here for help</xsl:attribute>
							</xsl:element>
						</xsl:if>
						<xsl:element name="input">
							<xsl:attribute name="type">hidden</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="$id"/>_hiddenName</xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="$caption"/></xsl:attribute>
						</xsl:element>
					</div>
				</xsl:when>
				<xsl:otherwise>
					<!-- Dynamic width layout -->
					<div class="divQCIcons">
						<xsl:if test="$enablespellcheck = 'true'">
							<xsl:if test="$spellCheck = 'true'">
								<img id="{$id}_spellCheck" name="{$id}_img" onClick="if (IAForms.isAccessible('{$id}')) SpellCheck({$id});" src="{$spellicon}" class="hand"/>
							</xsl:if>
						</xsl:if>
						<xsl:if test="normalize-space($help)">
							<xsl:element name="img">
								<xsl:attribute name="id"><xsl:value-of select="$id"/>_helpIcon</xsl:attribute>
								<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
								<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpTextIfAccessible(string($caption), string(normalize-space($help)), string($id))"/></xsl:attribute>
								<xsl:attribute name="class">hand</xsl:attribute>
								<xsl:attribute name="title">Click here for help</xsl:attribute>
							</xsl:element>
						</xsl:if>
						<xsl:element name="input">
							<xsl:attribute name="type">hidden</xsl:attribute>
							<xsl:attribute name="name"><xsl:value-of select="$id"/>_hiddenName</xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="$caption"/></xsl:attribute>
						</xsl:element>
					</div>
					<div class="divQCQuestion">
						<xsl:copy-of select="$userinput"/>
					</div>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<!-- =========================================================
	 Name:			textInputV2

	 Description:	Output a generic text question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="textInputV2">
		<xsl:param name="reqdClass"/>
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="protvalue">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<xsl:element name="input">
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="@type"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
			<!-- the document title needs to be updated to reflect any changes to the patient surname -->
			<xsl:if test="@id = 'patient_surname'">
				<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
			</xsl:if>
			<!-- the document title needs to be updated to reflect any changes to the patient forname -->
			<xsl:if test="@id = 'patient_forename'">
				<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
			</xsl:if>
			<!-- the document title needs to be updated to reflect any changes to the patient chi -->
			<xsl:if test="@id = 'chi'">
				<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
			</xsl:if>
			<!-- the document title needs to be updated to reflect any changes to the patient hcn -->
			<xsl:if test="@id = 'hcn'">
				<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
			</xsl:if>
			<!-- the document title needs to be updated to reflect any changes to the patient nhs number -->
			<xsl:if test="@id = 'patient_nhs_number'">
				<xsl:attribute name="onblur">UpdateTitle();</xsl:attribute>
			</xsl:if>
			<xsl:if test="@width != '' or @height!=''">
				<xsl:attribute name="style"><xsl:if test="@width !=''"><xsl:text>width: </xsl:text><xsl:value-of select="@width"/><xsl:text>px; </xsl:text></xsl:if><xsl:if test="@height !=''"><xsl:text>height: </xsl:text><xsl:value-of select="@height"/>px;</xsl:if>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="@onkeydown != ''">
				<xsl:attribute name="onkeydown"><xsl:value-of select="@onkeydown"/></xsl:attribute>
			</xsl:if>
			<xsl:attribute name="class" xml:space="preserve">questionInput <xsl:value-of select="$reqdClass"/></xsl:attribute>
			<xsl:if test="@readonly = 'true'">
				<xsl:attribute name="readonly">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@maxlength != ''">
				<xsl:attribute name="maxLength"><xsl:value-of select="@maxlength"/></xsl:attribute>
			</xsl:if>
			<xsl:attribute name="value">
				<xsl:choose>
					<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value">
						<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="@initialValue"><xsl:value-of select="@initialValue"/></xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>
	<!-- =========================================================
	 Name:			textAreaInputV2

	 Description:	Output a generic textArea question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="textAreaInputV2">
		<xsl:param name="reqdClass"/>
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="protvalue">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<xsl:element name="textArea">
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:choose>
				<!-- Sets row height -->
				<xsl:when test="@rows!=''">
					<xsl:attribute name="rows"><xsl:value-of select="@rows"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="rows">6</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="@onkeydown != ''">
				<xsl:attribute name="onkeydown"><xsl:value-of select="@onkeydown"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@readonly = 'true'">
				<xsl:attribute name="readonly">true</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="class" xml:space="preserve">questionInput <xsl:value-of select="$reqdClass"/></xsl:attribute>
			<xsl:if test="@width != '' or @height!=''">
				<xsl:attribute name="style"><xsl:if test="@width !=''"><xsl:text>width: </xsl:text><xsl:value-of select="@width"/><xsl:text>px; </xsl:text></xsl:if><xsl:if test="@height !=''"><xsl:text>height: </xsl:text><xsl:value-of select="@height"/>px;</xsl:if>
				</xsl:attribute>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value">
					<xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="@initialValue"><xsl:value-of select="@initialValue"/></xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<!-- =========================================================
	 Name:			dateInputV2

	 Description:	Output a generic date question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="dateInputV2">
		<xsl:param name="reqdClass"/>
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="protvalue">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<!-- Output input field -->
		<xsl:element name="input">
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">text</xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:if test="not(@readonly = 'true')">
				<xsl:choose>
					<!-- If we are dealing with a patient DOB then we will need to format the date 
					     and update the document title to reflect the change -->
					<xsl:when test="@id = 'patient_dob'">
						<xsl:attribute name="onblur">DateOfBirthUnambiguousDateEntry(this);</xsl:attribute>
					</xsl:when>
					<!-- All other dates only have to be formatted -->
					<xsl:otherwise>
						<xsl:attribute name="onblur">UnambiguousDateEntry(this);</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="interActivityRule">
					<xsl:attribute name="onChange">generalInputChange_<xsl:value-of select="@id"/></xsl:attribute>
				</xsl:if>
			</xsl:if>
			<xsl:attribute name="class" xml:space="preserve">questionInput dateInput <xsl:value-of select="$reqdClass"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/></xsl:attribute>
			<xsl:if test="@readonly = 'true'">
				<xsl:attribute name="readonly">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@width != '' or @height!=''">
				<xsl:attribute name="style"><xsl:if test="@width !=''"><xsl:text>width: </xsl:text><xsl:value-of select="@width"/><xsl:text>px; </xsl:text></xsl:if><xsl:if test="@height !=''"><xsl:text>height: </xsl:text><xsl:value-of select="@height"/>px;</xsl:if>
				</xsl:attribute>
			</xsl:if>
		</xsl:element>
		<!-- Spacer -->
		<xsl:text/>
		<!-- Output datepicker button -->
		<xsl:choose>
			<xsl:when test="@readonly = 'true'">
				<!-- Do not display any image -->
			</xsl:when>
			<xsl:otherwise>
				<img id="{@id}_dateIcon" name="{@id}_img" onClick="if (IAForms.isAccessible('{@id}')) ShowCalendar({@id}, {@id});" src="{$dateicon}" class="hand"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- =========================================================
	 Name:			checkBoxInputV2

	 Description:	Output a generic check box question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="checkBoxInputV2">
		<xsl:param name="reqdClass"/>
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="protvalue">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<xsl:element name="input">
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">checkbox</xsl:attribute>
			<xsl:attribute name="style">width:16px</xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:if test="@readonly = 'true'">
				<xsl:attribute name="readonly">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@hidden ='true'">
				<xsl:attribute name="style">display:none</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="class" xml:space="preserve">questionInput <xsl:value-of select="$reqdClass"/></xsl:attribute>
			<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = 'true'">
				<xsl:attribute name="checked">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@width != '' or @height!=''">
				<xsl:attribute name="style"><xsl:if test="@width !=''"><xsl:text>width: </xsl:text><xsl:value-of select="@width"/><xsl:text>px; </xsl:text></xsl:if><xsl:if test="@height !=''"><xsl:text>height: </xsl:text><xsl:value-of select="@height"/>px;</xsl:if>
				</xsl:attribute>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<!-- =========================================================
	 Name:			radioButtonInputV2

	 Description:	Output a generic radio button question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="radioButtonInputV2">
		<xsl:param name="reqdClass"/>
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="protvalue">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<div class="divRadioGroup">
			<xsl:for-each select="option">
				<xsl:element name="div">
					<xsl:if test="parent::node()/attribute::alignment='horizontal'">
						<xsl:attribute name="class">floatLeft</xsl:attribute>
					</xsl:if>
					<xsl:if test="parent::node()/attribute::width != '' or parent::node()/attribute::height !=''">
						<xsl:attribute name="style"><xsl:if test="parent::node()/attribute::width !=''"><xsl:text>width: </xsl:text><xsl:value-of select="parent::node()/attribute::width"/><xsl:text>px; </xsl:text></xsl:if><xsl:if test="parent::node()/attribute::height !=''"><xsl:text>height: </xsl:text><xsl:value-of select="parent::node()/attribute::height"/>px;</xsl:if>
						</xsl:attribute>
					</xsl:if>
					<xsl:element name="input">
						<xsl:attribute name="type">radio</xsl:attribute>
						<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/></xsl:attribute>
						<xsl:attribute name="id"><xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="position()"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
						<xsl:if test="@hidden ='true'">
							<xsl:attribute name="style">display:none</xsl:attribute>
						</xsl:if>
						<xsl:if test="parent::node()/attribute::onclick !=''">
							<xsl:attribute name="onclick"><xsl:value-of select="parent::node()/attribute::onclick"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="@readonly = 'true'">
							<xsl:attribute name="readonly">true</xsl:attribute>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$protvalue]) &gt; 0">
								<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = @value">
									<xsl:attribute name="checked">true</xsl:attribute>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="@isDefault ='true'">
									<xsl:attribute name="checked">true</xsl:attribute>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="class" xml:space="preserve">radioOption <xsl:value-of select="$reqdClass"/></xsl:attribute>
					</xsl:element>
					<xsl:element name="label">
						<xsl:attribute name="for"><xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="position()"/></xsl:attribute>
						<xsl:attribute name="class">radioOptionText</xsl:attribute>
						<xsl:value-of select="@text"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</div>
	</xsl:template>
	<!-- =========================================================
	 Name:			dropDownInputV2

	 Description:	Output a generic drop down list question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="dropDownInputV2">
		<xsl:param name="reqdClass"/>
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="protvalue">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<xsl:element name="select">
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="class" xml:space="preserve">questionInput <xsl:value-of select="$reqdClass"/></xsl:attribute>
			<xsl:if test="@hidden ='true'">
				<xsl:attribute name="style">display:none</xsl:attribute>
			</xsl:if>
			<xsl:if test="@width != '' or @height!=''">
				<xsl:attribute name="style"><xsl:if test="@width !=''"><xsl:text>width: </xsl:text><xsl:value-of select="@width"/><xsl:text>px; </xsl:text></xsl:if><xsl:if test="@height !=''"><xsl:text>height: </xsl:text><xsl:value-of select="@height"/>px;</xsl:if>
				</xsl:attribute>
			</xsl:if>
			<xsl:for-each select="option">
				<xsl:element name="option">
					<xsl:attribute name="id"><xsl:value-of select="parent::node()/attribute::id"/>_<xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
					<xsl:choose>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$protvalue]) &gt; 0">
							<xsl:if test="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value = @value">
								<xsl:attribute name="selected">true</xsl:attribute>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="normalize-space(@isDefault)">
								<xsl:attribute name="selected">true</xsl:attribute>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:value-of select="@text"/>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<!-- =========================================================
	 Name:			hiddenInputV2

	 Description:	Output a generic hidden question in renderVersion 2 (Interactive Forms) format
	 ========================================================= -->
	<xsl:template name="hiddenInputV2">
		<xsl:param name="reqdClass"/>
		<xsl:element name="input">
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">hidden</xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
			<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
			<xsl:variable name="toconvert">
				<xsl:value-of select="@id"/>
			</xsl:variable>
			<xsl:variable name="protvalue">
				<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
			</xsl:variable>
			<xsl:attribute name="value"><xsl:value-of select="//messagexml/prtobjcts/prtobjct[@id=$protvalue]/attribute::value"/></xsl:attribute>
		</xsl:element>
	</xsl:template>
	<!-- =========================================================
	 Name:			IAFormsScriptBuilder

	 Description:	Creates the javascript for interactive forms, including document ready script and the change routines for each 
						control that has interactive actions configured.
	 ========================================================= -->
	<xsl:template match="question[@type='dynaTable' or @type='giDynaTable']" mode="V2">
		<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
		<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
		<xsl:variable name="toconvert">
			<xsl:value-of select="@id"/>
		</xsl:variable>
		<xsl:variable name="tableid">
			<xsl:value-of select="translate($toconvert,$ucletters,$lcletters)"/>
		</xsl:variable>
		<div id="divQC_{@id}">
			<xsl:attribute name="class">dataTableContent</xsl:attribute>
			<table width="98%" cellspacing="0">
				<!-- <tr height="5"><td colspan="3"></td></tr> -->
				<tr>
					<td width="*" align="left">
						<font class="tableCaption">
							<xsl:value-of select="@text"/>
						</font>
					</td>
					<xsl:element name="td">
						<xsl:attribute name="align">center</xsl:attribute>
						<xsl:attribute name="class">buttonup</xsl:attribute>
						<xsl:attribute name="style">width:80;display:none;</xsl:attribute>
						<xsl:attribute name="onClick">ShowHideDeletedRows("<xsl:value-of select="@id"/>")</xsl:attribute>
						<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
						<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
						<xsl:attribute name="title">Click here to hide deleted rows</xsl:attribute>
						<xsl:attribute name="id">showHideDeleted_<xsl:value-of select="@id"/></xsl:attribute>Hide Deleted Rows</xsl:element>
					<xsl:element name="td">
						<xsl:attribute name="align">center</xsl:attribute>
						<xsl:attribute name="class">buttonup</xsl:attribute>
						<xsl:attribute name="style">width:80;</xsl:attribute>
						<xsl:attribute name="onClick">addRow("<xsl:value-of select="@id"/>")</xsl:attribute>
						<xsl:attribute name="onMouseOver">buttonOver(this)</xsl:attribute>
						<xsl:attribute name="onMouseOut">buttonOut(this)</xsl:attribute>
						<xsl:attribute name="title">Click here to add a new row</xsl:attribute>
						<xsl:attribute name="id">addRow_<xsl:value-of select="@id"/></xsl:attribute>Add Row</xsl:element>
					<td class="help">
						<xsl:if test="normalize-space(@help)">
							<xsl:element name="img">
								<xsl:attribute name="src"><xsl:value-of select="$helpicon"/></xsl:attribute>
								<xsl:attribute name="onClick"><xsl:value-of disable-output-escaping="yes" select="user:returnHelpText(string(@text), string(normalize-space(@help)))"/></xsl:attribute>
								<xsl:attribute name="class">hand</xsl:attribute>
								<xsl:attribute name="title">Click here for help</xsl:attribute>
							</xsl:element>
						</xsl:if>
					</td>
				</tr>
			</table>
			<div align="left" class="dynaTable">
				<xsl:element name="input">
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@id"/>_rowCount</xsl:attribute>
					<xsl:choose>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) = 0">
							<xsl:attribute name="value">1</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="value"><xsl:value-of select="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row)"/></xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<table cellspacing="2" width="100%" id="{@id}">
					<tr>
						<xsl:element name="th">
						</xsl:element>
						<!-- Note that we do not output a heading caption for table questions -->
						<!-- Output columns - the first and last are blank -->
						<xsl:for-each select="column">
							<xsl:element name="th">
								<xsl:call-template name="addHiddenCellClass"/>
								<xsl:value-of select="@text"/>
								<xsl:element name="input">
									<xsl:attribute name="type">hidden</xsl:attribute>
									<xsl:attribute name="name"><xsl:value-of select="parent::node()/attribute::id"/>___<xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
									<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
								</xsl:element>
								<xsl:if test="@spellcheck='true'">
									<xsl:if test="$enablespellcheck = 'true'">
										<xsl:element name="img">
											<xsl:attribute name="src"><xsl:value-of select="$spellicon"/></xsl:attribute>
											<xsl:attribute name="class">hand</xsl:attribute>
											<xsl:attribute name="align">right</xsl:attribute>
											<xsl:attribute name="onClick">SpellCheckColumn("<xsl:value-of select="$tableid"/>", "<xsl:value-of select="@id"/>")</xsl:attribute>
										</xsl:element>
									</xsl:if>
								</xsl:if>
							</xsl:element>
						</xsl:for-each>
						<th>
							<xsl:element name="input">
								<xsl:attribute name="type">hidden</xsl:attribute>
								<xsl:attribute name="name"><xsl:value-of select="@id"/>_hiddenName</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="@text"/></xsl:attribute>
							</xsl:element>
						</th>
					</tr>
					<!-- write the rows out.  -->
					<xsl:variable name="orgtableid">
						<xsl:value-of select="@id"/>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]) = 0">
							<xsl:call-template name="dynaTableRow">
								<xsl:with-param name="tableid" select="$tableid"/>
								<xsl:with-param name="orgtableid" select="$orgtableid"/>
								<xsl:with-param name="rowid" select="1"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]) &gt; 0">
							<xsl:choose>
								<!-- Create as many rows as there are rows in the data xml-->
								<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) &gt; 0">
									<xsl:for-each select="//messagexml/prtobjcts/prtobjct[@id=$tableid]/row">
										<xsl:call-template name="dynaTableRow">
											<xsl:with-param name="tableid" select="$tableid"/>
											<xsl:with-param name="orgtableid" select="$orgtableid"/>
											<xsl:with-param name="rowid" select="@id"/>
										</xsl:call-template>
									</xsl:for-each>
								</xsl:when>
								<xsl:when test="count(//messagexml/prtobjcts/prtobjct[@id=$tableid]/row) &lt; 1">
									<xsl:call-template name="dynaTableRow">
										<xsl:with-param name="tableid" select="$tableid"/>
										<xsl:with-param name="orgtableid" select="$orgtableid"/>
										<xsl:with-param name="rowid" select="1"/>
									</xsl:call-template>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</table>
				<br/>
			</div>
		</div>
	</xsl:template>
	<!-- =========================================================
	 Name:			IAFormsScriptBuilder

	 Description:	Creates the javascript for interactive forms, including document ready script and the change routines for each 
						control that has interactive actions configured.
	 ========================================================= -->
	<xsl:template name="IAFormsScriptBuilder">
		<script type="text/javascript">
			$(document).ready(function() {
				IAForms.initialise();
				<xsl:for-each select="//question[@renderVersion>'1' and @type='select' and option/interActivityActions]">
					$('#<xsl:value-of select="@id"/>').change(function(){ddChange_<xsl:value-of select="@id"/>(this.value);});
					ddChange_<xsl:value-of select="@id"/>($('#<xsl:value-of select="@id"/>').val());
				</xsl:for-each>
			<xsl:for-each select="//question[@renderVersion>'1' and @type='check' and (checkedActions or clearedActions)]">
				<xsl:call-template name="checkBoxOnChangeCall"/>
					checkBoxChange_<xsl:value-of select="@id"/>($('#<xsl:value-of select="@id"/>').attr("checked"));
				</xsl:for-each>
			<xsl:for-each select="//question[@renderVersion>'1' and @type='radio' and option/interActivityActions]">
				<xsl:call-template name="radioButtonOnClickCall"/>
			</xsl:for-each>
			<xsl:for-each select="//question[@renderVersion>'1' and interActivityRule]">
					$('#<xsl:value-of select="@id"/>').change(function(){generalInputChange_<xsl:value-of select="@id"/>(this.value);});
					generalInputChange_<xsl:value-of select="@id"/>($('#<xsl:value-of select="@id"/>').val());
				</xsl:for-each>
			});
			<!-- Output the actual function definitions -->
			<xsl:for-each select="//question[@renderVersion>'1' and @type='select' and option/interActivityActions]">
				<xsl:call-template name="dropDownInputV2_IAFFunctions"/>
			</xsl:for-each>
			<xsl:for-each select="//question[@renderVersion>'1' and @type='radio' and option/interActivityActions]">
				<xsl:call-template name="radioButtonInputV2_IAFFunctions"/>
			</xsl:for-each>
			<xsl:for-each select="//question[@renderVersion>'1' and @type='check' and (checkedActions or clearedActions)]">
				<xsl:call-template name="checkBoxInputV2_IAFFunctions"/>
			</xsl:for-each>
			<xsl:for-each select="//question[@renderVersion>'1' and interActivityRule]">
				<xsl:call-template name="generalInputV2_IAFFunctions"/>
			</xsl:for-each>
		</script>
	</xsl:template>
	<!--
=================================================================================================
Name:			dropDownInputV2_IAFFunctions
Description:	Outputs the javascript function to perform the interactivity actions when a drop down input selection is made
=================================================================================================
-->
	<xsl:template name="dropDownInputV2_IAFFunctions">
		<xsl:variable name="tmpId" select="@id"/>
	function ddChange_<xsl:value-of select="@id"/>(v) {
		// alert('ddChange_<xsl:value-of select="@id"/>(' + v + ')');
		switch (v)
		{<xsl:for-each select="option[interActivityActions[actionSetVisible | actionSetRequired | actionSetEnabled | actionSetDisplay | actionSetValue]]">
			<xsl:variable name="tmpValue" select="@value"/>
			case '<xsl:value-of select="$tmpValue"/>':
				<xsl:for-each select="interActivityActions/*">
				<xsl:apply-templates select="." mode="DoActionCall"/>
			</xsl:for-each>
				break;
		</xsl:for-each>}
	}
</xsl:template>
	<!--
=================================================================================================
Name:			radioButtonOnClickCall
Description:	Outputs the javascript function call to perform the interactivity actions when a radioButtonInput selection is made
=================================================================================================
-->
	<xsl:template name="radioButtonOnClickCall">
		<xsl:variable name="tmpId" select="@id"/>
		<xsl:for-each select="option[interActivityActions]">
		$('#<xsl:value-of select="$tmpId"/>_<xsl:value-of select="position()"/>').change(function() {radioChange_<xsl:value-of select="$tmpId"/>(this.value)});
	$('#<xsl:value-of select="$tmpId"/>_<xsl:value-of select="position()"/>').each(function(){if (this.getAttribute('checked')==true) { radioChange_<xsl:value-of select="$tmpId"/>(this.value); } });
	</xsl:for-each>
	</xsl:template>
	<!--
=================================================================================================
Name:			radioButtonInputV2_IAFFunctions
Description:	Outputs the javascript function to perform the interactivity actions when a radioButtonInput selection is made
=================================================================================================
-->
	<xsl:template name="radioButtonInputV2_IAFFunctions">
	function radioChange_<xsl:value-of select="@id"/>(v) {
		switch (v)
		{<xsl:for-each select="option[interActivityActions[actionSetVisible | actionSetRequired | actionSetEnabled | actionSetDisplay | actionSetValue]]">
			<xsl:variable name="tmpValue" select="@value"/>
			case '<xsl:value-of select="$tmpValue"/>':
				<xsl:for-each select="interActivityActions/*">
				<xsl:apply-templates select="." mode="DoActionCall"/>
			</xsl:for-each>
			break;
		</xsl:for-each>}
	}
</xsl:template>
	<!--
=================================================================================================
Name:			checkBoxOnChangeCall
Description:	Outputs the javascript function call to perform the interactivity actions when a checkBoxInput change is made
=================================================================================================
-->
	<xsl:template name="checkBoxOnChangeCall">
		$('#<xsl:value-of select="@id"/>').change(function(){checkBoxChange_<xsl:value-of select="@id"/>(this.getAttribute("checked"));});
</xsl:template>
	<!--
=================================================================================================
Name:			checkBoxInputV2_IAFFunctions
Description:	Outputs the javascript function to perform the interactivity actions when a checkBoxInput change is made
=================================================================================================
-->
	<xsl:template name="checkBoxInputV2_IAFFunctions">
	function checkBoxChange_<xsl:value-of select="@id"/>(checked) {
		if (checked) {
			<xsl:for-each select="checkedActions/*">
			<xsl:apply-templates select="." mode="DoActionCall"/>
		</xsl:for-each>
		}
		else {
			<xsl:for-each select="clearedActions/*">
			<xsl:apply-templates select="." mode="DoActionCall"/>
		</xsl:for-each>
		}
	}
</xsl:template>
	<!--
=================================================================================================
Name:			generalInputV2_IAFFunctions
Description:	Outputs the javascript function to perform the interactivity actions when a textInput, textAreaInput or dateInput change is
					made.
=================================================================================================
-->
	<xsl:template name="generalInputV2_IAFFunctions">
	function generalInputChange_<xsl:value-of select="@id"/>(inputVal) {
	<xsl:for-each select="interActivityRule">
		if (<xsl:for-each select="interActivityTests/test">
				<xsl:apply-templates select="." mode="DoTestCall">
					<xsl:with-param name="position">
						<xsl:value-of select="position()"/>
					</xsl:with-param>
				</xsl:apply-templates>
			</xsl:for-each>) {
			<xsl:for-each select="interActivityActions/*">
				<xsl:apply-templates select="." mode="DoActionCall"/>
			</xsl:for-each>
		}
	</xsl:for-each>
	}
</xsl:template>
	<!--
=================================================================================================
Match:			interActivityTests/test
Description:	Outputs the javascript to perform a single test which must pass in order to perform the interActivityActions
=================================================================================================
-->
	<xsl:template match="interActivityTests/test" mode="DoTestCall">
		<xsl:param name="position"/>
		<xsl:if test="$position > 1"> &amp;&amp; </xsl:if>IAForms.testInputValue('<xsl:value-of select="@comparison"/>', '<xsl:value-of select="@value"/>', inputVal)</xsl:template>
	<!--
=================================================================================================
Description:	Outputs the javascript function call to perform the interactivity action, matches on actionSetVisible or actionSetRequired
					or actionSetEnabled or actionSetDisplay or actionSetValue
=================================================================================================
-->
	<xsl:template match="actionSetVisible | actionSetRequired | actionSetEnabled | actionSetDisplay | actionSetValue" mode="DoActionCall">
		<xsl:choose>
			<xsl:when test="name()='actionSetVisible'">IAForms.setVisibility('<xsl:value-of select="@targetID"/>', '<xsl:value-of select="@value"/>');</xsl:when>
			<xsl:when test="name()='actionSetRequired'">IAForms.setRequired('<xsl:value-of select="@targetID"/>', '<xsl:value-of select="@value"/>');</xsl:when>
			<xsl:when test="name()='actionSetEnabled'">IAForms.setEnabled('<xsl:value-of select="@targetID"/>', '<xsl:value-of select="@value"/>');</xsl:when>
			<xsl:when test="name()='actionSetDisplay'">IAForms.setDisplay('<xsl:value-of select="@targetID"/>', '<xsl:value-of select="@value"/>');</xsl:when>
			<xsl:when test="name()='actionSetValue'">IAForms.setValue('<xsl:value-of select="@targetID"/>', '<xsl:value-of select="@value"/>');</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- 
===============================================================================================
	Name:			control
	Description:		sets up the dropdowns and clientside events for the referrer and registrar controls
	================================================================================================ -->
	<xsl:template match="control" mode="V2">
		<xsl:call-template name="referrerOrRegistrarControl"/>
	</xsl:template>
	<!--
==================================================================================================
==================================================================================================
 C O M M O N      T E M P L A T E S      U S E D      B Y      B O T H      S T Y L E S H E E TS
==================================================================================================
==================================================================================================
-->
	<!-- 
===============================================================================================
	Name:			referrerOrRegistrarControl
	Description:		sets up the dropdowns and clientside events for the referrer and registrar controls
	================================================================================================ -->
	<xsl:template name="referrerOrRegistrarControl">
		<xsl:choose>
			<xsl:when test="SenderDetails">
				<xsl:element name="input">
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="id"><xsl:value-of select="@name"/>controls</xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@name"/>controls</xsl:attribute>
					<xsl:attribute name="value">xmlsenderdetails<xsl:value-of select="@name"/></xsl:attribute>
				</xsl:element>
				<xsl:element name="table">
					<xsl:attribute name="cellSpacing">0</xsl:attribute>
					<xsl:apply-templates select="SenderDetails"/>
				</xsl:element>
				<!-- Stick the Sender xml onto the page-->
				<xsl:element name="xml">
					<xsl:attribute name="id">xmlsenderdetails<xsl:value-of select="@name"/></xsl:attribute>
					<xsl:attribute name="name">xmlsenderdetails<xsl:value-of select="@name"/></xsl:attribute>
					<xsl:copy-of select="SenderDetails"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="input">
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="id"><xsl:value-of select="@name"/>controls</xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@name"/>controls</xsl:attribute>
					<xsl:attribute name="value">xml<xsl:value-of select="@name"/>;<xsl:value-of select="descendant::hces[last()]/@hcetypename"/></xsl:attribute>
				</xsl:element>
				<xsl:element name="table">
					<xsl:attribute name="cellSpacing">0</xsl:attribute>
					<xsl:apply-templates select="hces"/>
				</xsl:element>
				<xsl:element name="xml">
					<xsl:attribute name="id">xml<xsl:value-of select="@name"/></xsl:attribute>
					<xsl:attribute name="name">xml<xsl:value-of select="xml"/><xsl:value-of select="@name"/></xsl:attribute>
					<xsl:copy-of select="hces"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="SenderDetails">
		<!--Location row-->
		<xsl:element name="tr">
			<xsl:element name="td">
				<xsl:attribute name="class">question</xsl:attribute>Location</xsl:element>
			<xsl:element name="td">
				<xsl:attribute name="width">*</xsl:attribute>
				<xsl:attribute name="nowrap">true</xsl:attribute>
				<xsl:element name="select">
					<xsl:attribute name="style">width:200px</xsl:attribute>
					<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Location</xsl:attribute>
					<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Location</xsl:attribute>
					<xsl:attribute name="onchange">vbscript:call locationChanged('<xsl:value-of select="ancestor-or-self::control/@name"/>')</xsl:attribute>
					<xsl:element name="option">
						<xsl:attribute name="value">-1</xsl:attribute>
						<xsl:attribute name="selected">true</xsl:attribute>
            -- Please Select --
					</xsl:element>
					<xsl:for-each select="Location">
						<option>
							<xsl:attribute name="value"><xsl:value-of select="LocationNationalCode/text()"/></xsl:attribute>
							<!--Select first in the list
							<xsl:if test="position() = 1">
								<xsl:attribute name="selected">true</xsl:attribute>
							</xsl:if>-->
							<xsl:value-of select="LocationName/text()"/>
						</option>
					</xsl:for-each>
				</xsl:element>
			</xsl:element>
		</xsl:element>
		<!-- Specialty Row-->
		<!-- If there are Specialties then display the row otherwise don't!-->
		<xsl:if test="//Specialty">
			<xsl:element name="tr">
				<xsl:element name="td">
					<xsl:attribute name="class">question</xsl:attribute>Specialty</xsl:element>
				<xsl:element name="td">
					<xsl:attribute name="width">*</xsl:attribute>
					<xsl:attribute name="nowrap">true</xsl:attribute>
					<xsl:element name="select">
						<xsl:attribute name="style">width:200px</xsl:attribute>
						<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Specialty</xsl:attribute>
						<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Specialty</xsl:attribute>
						<xsl:attribute name="onchange">vbscript:call specialtyChanged('<xsl:value-of select="ancestor-or-self::control/@name"/>')</xsl:attribute>
						<xsl:element name="option">
							<xsl:attribute name="value">-1</xsl:attribute>
							<xsl:attribute name="selected">true</xsl:attribute>
							<xsl:attribute name="text"/>
						</xsl:element>
/					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<!-- Hcp row -->
		<!-- Always display this row but only attempt populate it initially if there are no specialties-->
		<xsl:element name="tr">
			<xsl:element name="td">
				<xsl:attribute name="class">question</xsl:attribute>HCP</xsl:element>
			<xsl:element name="td">
				<xsl:attribute name="width">*</xsl:attribute>
				<xsl:attribute name="nowrap">true</xsl:attribute>
				<xsl:element name="select">
					<xsl:attribute name="style">width:200px</xsl:attribute>
					<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Hcp</xsl:attribute>
					<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/>Hcp</xsl:attribute>
					<xsl:attribute name="onchange">vbscript:call hcpChanged('<xsl:value-of select="ancestor-or-self::control/@name"/>')</xsl:attribute>
					<xsl:element name="option">
						<xsl:attribute name="value">-1</xsl:attribute>
						<xsl:attribute name="selected">true</xsl:attribute>
						<xsl:attribute name="text"/>
					</xsl:element>
/					</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="hces">
		<xsl:if test="position() = 1">
			<xsl:element name="tr">
				<xsl:element name="td">
					<xsl:attribute name="class">question</xsl:attribute>
					<xsl:value-of select="@hcetypename"/>
				</xsl:element>
				<xsl:element name="td">
					<xsl:attribute name="width">*</xsl:attribute>
					<xsl:attribute name="nowrap">true</xsl:attribute>
					<xsl:element name="select">
						<xsl:attribute name="style">width:200px</xsl:attribute>
						<xsl:attribute name="id">cmb<xsl:value-of select="ancestor-or-self::control/@name"/><xsl:value-of select="@hcetypename"/></xsl:attribute>
						<xsl:attribute name="name">cmb<xsl:value-of select="ancestor-or-self::control/@name"/><xsl:value-of select="@hcetypename"/></xsl:attribute>
						<!-- Change to clear all fields when Blank entry is selected in GP Practice combo -->
						<xsl:if test="(count(ancestor::hces) = 0) and (contains(ancestor-or-self::control/@name, 'referrer'))">
							<xsl:attribute name="onchange">vbscript:call clearTopLevelDetailsFields('<xsl:value-of select="ancestor-or-self::control/@name"/>',  '<xsl:value-of select="/descendant::hces[position()=1]/@hcetypename"/>', false)</xsl:attribute>
						</xsl:if>
						<!-- End Change -->
						<xsl:if test="count(descendant::hces) = 0">
							<xsl:attribute name="onchange">vbscript:call setFieldValuesFromControl('<xsl:value-of select="ancestor-or-self::control/@name"/>', '<xsl:value-of select="//hces/descendant::hces[last()]/@hcetypename"/>', 'false')</xsl:attribute>
						</xsl:if>
						<xsl:if test="(count(descendant::hces) != 0) and (count(ancestor::hces) != 0)">
							<xsl:attribute name="onchange">vbscript:call loadHces('xml<xsl:value-of select="ancestor-or-self::control/@name"/>', 'cmb<xsl:value-of select="ancestor-or-self::control/@name"/><xsl:value-of select="string(hce/hces/@hcetypename)"/>')</xsl:attribute>
						</xsl:if>
						<xsl:if test="count(ancestor::hces) != 0">
							<xsl:element name="option">
								<xsl:attribute name="value">-1</xsl:attribute>
								<xsl:attribute name="text"/>
							</xsl:element>
						</xsl:if>
						<!-- if there is a default parent hce, or if there is only one parent hce or no parent hce-->
						<xsl:if test="(count(ancestor::hces[position()=1]/hce[@isDefault='true']) = 1) or (count(ancestor::hces[position()=1]/hce) = 1) or (count(ancestor::hces[position()=1]/hce) = 0)">
							<xsl:apply-templates select="hce"/>
						</xsl:if>
					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<xsl:apply-templates select="hce/hces"/>
	</xsl:template>
	<xsl:template match="hce">
		<!-- This adds the blank entry for top level HCE -->
		<xsl:if test="(count(ancestor-or-self::hce[@isDefault='true'] )= 1) and (count(ancestor::hces) = 1) and (contains(ancestor-or-self::control/@name, 'referrer'))">
			<xsl:element name="option">
				<xsl:attribute name="value">-1</xsl:attribute>
				<xsl:attribute name="text"/>
			</xsl:element>
		</xsl:if>
		<!-- End of Change -->
		<xsl:element name="option">
			<xsl:attribute name="value"><xsl:value-of select="@hceid"/></xsl:attribute>
			<xsl:if test="@isDefault='true'">
				<xsl:attribute name="selected">true</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="@hcename"/>
			<xsl:if test="@type!=''">(<xsl:value-of select="@type"/>)</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template name="addHiddenCellClass">
		<xsl:if test="@hidden = 'true' or @display='hidden' or @display='hiddenPost'">
			<xsl:attribute name="class">hiddenCell</xsl:attribute>
		</xsl:if>
	</xsl:template>
	<!-- Script functions required during processing -->
	<msxsl:script language="VBScript" implements-prefix="user"><![CDATA[

	   function returnHelpText(strName, strHelp)
		returnHelpText = "javascript:helpText ('" & Replace(strHelp, "'", "\'") & "', '" & Replace(strName, "'", "\'") & "')"
	   end function
	   
		function returnHelpTextIfAccessible(strName, strHelp, strId)
			returnHelpTextIfAccessible = "javascript:if (IAForms.isAccessible('" & strId & "')) helpText('" & Replace(strHelp, "'", "\'") & "', '" & Replace(strName, "'", "\'") & "')"
		end function


	]]></msxsl:script>
</xsl:stylesheet>
